"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtPrintSupport import *
import enum


class QPrinter(QtGui.QPagedPaintDevice):
    """
    https://doc.qt.io/qt-6/qprinter.html

    **Detailed Description**

    This device represents a series of pages of printed output, and is used in
    almost exactly the same way as other paint devices such as **QWidget**  and
    **QPixmap** . A set of additional functions are provided to manage device-
    specific features, such as orientation and resolution, and to step through
    the pages in a document as it is generated.

    When printing directly to a printer on Windows or macOS, QPrinter uses the
    built-in printer drivers. On X11, QPrinter uses the **Common Unix Printing
    System (CUPS)**  to send PDF output to the printer. As an alternative, the
    **printProgram** () function can be used to specify the command or utility
    to use instead of the system default.

    Note that setting parameters like paper size and resolution on an invalid
    printer is undefined. You can use **QPrinter::isValid** () to verify this
    before changing any parameters.

    QPrinter supports a number of parameters, most of which can be changed by
    the end user through a **print dialog** . In general, QPrinter passes these
    functions onto the underlying **QPrintEngine** .

    The most important parameters are:

    * **setPageLayout** () tells QPrinter which page orientation to use, and
    what size to expect from the printer.
      * **setResolution** () tells
    QPrinter what resolution you wish the printer to provide, in dots per inch
    (DPI).
      * **setFullPage** () tells QPrinter whether you want to deal with
    the full page or just with the part the printer can draw on.
      *
    **setCopyCount** () tells QPrinter how many copies of the document it should
    print.

    Many of these functions can only be called before the actual printing begins
    (i.e., before **QPainter::begin** () is called). This usually makes sense
    because, for example, it's not possible to change the number of copies when
    you are halfway through printing. There are also some settings that the user
    sets (through the printer dialog) and that applications are expected to
    obey. See **QAbstractPrintDialog** 's documentation for more details.

    When **QPainter::begin** () is called, the QPrinter it operates on is
    prepared for a new page, enabling the **QPainter**  to be used immediately
    to paint the first page in a document. Once the first page has been painted,
    **newPage** () can be called to request a new blank page to paint on, or
    **QPainter::end** () can be called to finish printing. The second page and
    all following pages are prepared using a call to **newPage** () before they
    are painted.

    The first page in a document does not need to be preceded by a call to
    **newPage** (). You only need to calling **newPage** () after
    **QPainter::begin** () if you need to insert a blank page at the beginning
    of a printed document. Similarly, calling **newPage** () after the last page
    in a document is painted will result in a trailing blank page appended to
    the end of the printed document.

    If you want to abort the print job, **abort** () will try its best to stop
    printing. It may cancel the entire job or just part of it.

    Since QPrinter can print to any **QPrintEngine**  subclass, it is possible
    to extend printing support to cover new types of printing subsystem by
    subclassing **QPrintEngine**  and reimplementing its interface.

    **See also** **QPrintDialog**  and **Qt Print Support** .
    """

    class DuplexMode(enum.Enum):
        DuplexNone: QPrinter = ...
        DuplexAuto: QPrinter = ...
        DuplexLongSide: QPrinter = ...
        DuplexShortSide: QPrinter = ...

    class Unit(enum.Enum):
        Millimeter: QPrinter = ...
        Point: QPrinter = ...
        Inch: QPrinter = ...
        Pica: QPrinter = ...
        Didot: QPrinter = ...
        Cicero: QPrinter = ...
        DevicePixel: QPrinter = ...

    class PrintRange(enum.Enum):
        AllPages: QPrinter = ...
        Selection: QPrinter = ...
        PageRange: QPrinter = ...
        CurrentPage: QPrinter = ...

    class OutputFormat(enum.Enum):
        NativeFormat: QPrinter = ...
        PdfFormat: QPrinter = ...

    class PrinterState(enum.Enum):
        Idle: QPrinter = ...
        Active: QPrinter = ...
        Aborted: QPrinter = ...
        Error: QPrinter = ...

    class PaperSource(enum.Enum):
        OnlyOne: QPrinter = ...
        Lower: QPrinter = ...
        Middle: QPrinter = ...
        Manual: QPrinter = ...
        Envelope: QPrinter = ...
        EnvelopeManual: QPrinter = ...
        Auto: QPrinter = ...
        Tractor: QPrinter = ...
        SmallFormat: QPrinter = ...
        LargeFormat: QPrinter = ...
        LargeCapacity: QPrinter = ...
        Cassette: QPrinter = ...
        FormSource: QPrinter = ...
        MaxPageSource: QPrinter = ...
        Upper: QPrinter = ...
        CustomSource: QPrinter = ...
        LastPaperSource: QPrinter = ...

    class ColorMode(enum.Enum):
        GrayScale: QPrinter = ...
        Color: QPrinter = ...

    class PageOrder(enum.Enum):
        FirstPageFirst: QPrinter = ...
        LastPageFirst: QPrinter = ...

    class PrinterMode(enum.Enum):
        ScreenResolution: QPrinter = ...
        PrinterResolution: QPrinter = ...
        HighResolution: QPrinter = ...

    @typing.overload
    def __init__(self, mode: "QPrinter.PrinterMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#QPrinter

        **QPrinter::QPrinter(QPrinter::PrinterMode mode = ScreenResolution)**

        Creates a new printer object with the given **mode**.
        """
        ...

    @typing.overload
    def __init__(
        self, printer: "QPrinterInfo", mode: "QPrinter.PrinterMode" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#QPrinter-1

        **QPrinter::QPrinter(const QPrinterInfo & printer ,
        QPrinter::PrinterMode mode = ScreenResolution)**

        Creates a new printer object with the given **printer** and **mode**.
        """
        ...

    def pdfVersion(self) -> QtGui.QPagedPaintDevice.PdfVersion:
        """
        https://doc.qt.io/qt-6/qprinter.html#pdfVersion

        **[since 5.10] QPagedPaintDevice::PdfVersion QPrinter::pdfVersion()
        const**

        Returns the PDF version for this printer. The default is
        `PdfVersion_1_4`.

        This function was introduced in Qt 5.10.

        **See also** **setPdfVersion** ().
        """
        ...

    def setPdfVersion(self, version: QtGui.QPagedPaintDevice.PdfVersion) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setPdfVersion

        **[since 5.10] void
        QPrinter::setPdfVersion(QPagedPaintDevice::PdfVersion version )**

        Sets the PDF version for this printer to **version**.

        If **version** is the same value as currently set then no change will be
        made.

        This function was introduced in Qt 5.10.

        **See also** **pdfVersion** ().
        """
        ...

    def setEngines(
        self, printEngine: QPrintEngine, paintEngine: QtGui.QPaintEngine
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setEngines

        **[protected] void QPrinter::setEngines(QPrintEngine * printEngine ,
        QPaintEngine * paintEngine )**

        This function is used by subclasses of **QPrinter**  to specify custom
        print and paint engines ( **printEngine** and **paintEngine** ,
        respectively).

        **QPrinter**  does not take ownership of the engines, so you need to
        manage these engine instances yourself.

        Note that changing the engines will reset the printer state and all its
        properties.

        **See also** **printEngine** (), **paintEngine** (), and
        **setOutputFormat** ().
        """
        ...

    def metric(self, a0: QtGui.QPaintDevice.PaintDeviceMetric) -> int:
        ...

    def printRange(self) -> "QPrinter.PrintRange":
        """
        https://doc.qt.io/qt-6/qprinter.html#printRange

        **QPrinter::PrintRange QPrinter::printRange() const**

        Returns the page range of the **QPrinter** . After the print setup
        dialog has been opened, this function returns the value selected by the
        user.

        **See also** **setPrintRange** ().
        """
        ...

    def setPrintRange(self, range: "QPrinter.PrintRange") -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setPrintRange

        **void QPrinter::setPrintRange(QPrinter::PrintRange range )**

        Sets the print range option in to be **range**.

        **See also** **printRange** ().
        """
        ...

    def toPage(self) -> int:
        """
        https://doc.qt.io/qt-6/qprinter.html#toPage

        **int QPrinter::toPage() const**

        Returns the number of the last page in a range of pages to be printed
        (the "to page" setting). Pages in a document are numbered according to
        the convention that the first page is page 1.

        By default, this function returns a special value of 0, meaning that the
        "to page" setting is unset.

        **Note:** If **fromPage** () and toPage() both return 0, this indicates
        that **the whole document will be printed**.

        The programmer is responsible for reading this setting and printing
        accordingly.

        **See also** **setFromTo** (), **fromPage** (), and **pageRanges** ().
        """
        ...

    def fromPage(self) -> int:
        """
        https://doc.qt.io/qt-6/qprinter.html#fromPage

        **int QPrinter::fromPage() const**

        Returns the number of the first page in a range of pages to be printed
        (the "from page" setting). Pages in a document are numbered according to
        the convention that the first page is page 1.

        By default, this function returns a special value of 0, meaning that the
        "from page" setting is unset.

        **Note:** If fromPage() and **toPage** () both return 0, this indicates
        that **the whole document will be printed**.

        **See also** **setFromTo** (), **toPage** (), and **pageRanges** ().
        """
        ...

    def setFromTo(self, fromPage: int, toPage: int) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setFromTo

        **void QPrinter::setFromTo(int from , int to )**

        Sets the range of pages to be printed to cover the pages with numbers
        specified by **from** and **to** , where **from** corresponds to the
        first page in the range and **to** corresponds to the last.

        **Note:** Pages in a document are numbered according to the convention
        that the first page is page 1. However, if **from** and **to** are both
        set to 0, the **whole document will be printed**.

        This function is mostly used to set a default value that the user can
        override in the print dialog when you call setup().

        **See also** **fromPage** (), **toPage** (), and **pageRanges** ().
        """
        ...

    def printEngine(self) -> QPrintEngine:
        """
        https://doc.qt.io/qt-6/qprinter.html#printEngine

        **QPrintEngine *QPrinter::printEngine() const**

        Returns the print engine used by the printer.
        """
        ...

    def paintEngine(self) -> QtGui.QPaintEngine:
        """
        https://doc.qt.io/qt-6/qprinter.html#paintEngine

        **[override virtual] QPaintEngine *QPrinter::paintEngine() const**

        Reimplements: **QPaintDevice::paintEngine() const** .

        Returns the paint engine used by the printer.
        """
        ...

    def printerState(self) -> "QPrinter.PrinterState":
        """
        https://doc.qt.io/qt-6/qprinter.html#printerState

        **QPrinter::PrinterState QPrinter::printerState() const**

        Returns the current state of the printer. This may not always be
        accurate (for example if the printer doesn't have the capability of
        reporting its state to the operating system).
        """
        ...

    def abort(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprinter.html#abort

        **bool QPrinter::abort()**

        Aborts the current print run. Returns `true` if the print run was
        successfully aborted and **printerState** () will return
        **QPrinter::Aborted** ; otherwise returns `false`.

        It is not always possible to abort a print job. For example, all the
        data has gone to the printer but the printer cannot or will not cancel
        the job when asked to.
        """
        ...

    def newPage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprinter.html#newPage

        **[override virtual] bool QPrinter::newPage()**

        Reimplements: **QPagedPaintDevice::newPage** ().

        Tells the printer to eject the current page and to continue printing on
        a new page. Returns `true` if this was successful; otherwise returns
        `false`.

        Calling newPage() on an inactive **QPrinter**  object will always fail.
        """
        ...

    def pageRect(self, a0: "QPrinter.Unit") -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qprinter.html#pageRect

        **QRectF QPrinter::pageRect(QPrinter::Unit unit ) const**

        Returns the page's rectangle in **unit** ; this is usually smaller than
        the **paperRect** () since the page normally has margins between its
        borders and the paper.

        **See also** **QPagedPaintDevice::pageLayout** ().
        """
        ...

    def paperRect(self, a0: "QPrinter.Unit") -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qprinter.html#paperRect

        **QRectF QPrinter::paperRect(QPrinter::Unit unit ) const**

        Returns the paper's rectangle in **unit** ; this is usually larger than
        the **pageRect** ().

        **See also** **pageRect** ().
        """
        ...

    def fontEmbeddingEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprinter.html#fontEmbeddingEnabled

        **bool QPrinter::fontEmbeddingEnabled() const**

        Returns `true` if font embedding is enabled.

        **See also** **setFontEmbeddingEnabled** ().
        """
        ...

    def setFontEmbeddingEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setFontEmbeddingEnabled

        **void QPrinter::setFontEmbeddingEnabled(bool enable )**

        Enabled or disables font embedding depending on **enable**.

        **See also** **fontEmbeddingEnabled** ().
        """
        ...

    def supportedResolutions(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qprinter.html#supportedResolutions

        **QList<int> QPrinter::supportedResolutions() const**

        Returns a list of the resolutions (a list of dots-per-inch integers)
        that the printer says it supports.

        For X11 where all printing is directly to PDF, this function will always
        return a one item list containing only the PDF resolution, i.e., 72 (72
        dpi -- but see **PrinterMode** ).
        """
        ...

    def duplex(self) -> "QPrinter.DuplexMode":
        """
        https://doc.qt.io/qt-6/qprinter.html#duplex

        **QPrinter::DuplexMode QPrinter::duplex() const**

        Returns the current duplex mode.

        **See also** **setDuplex** ().
        """
        ...

    def setDuplex(self, duplex: "QPrinter.DuplexMode") -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setDuplex

        **void QPrinter::setDuplex(QPrinter::DuplexMode duplex )**

        Enables double sided printing based on the **duplex** mode.

        **See also** **duplex** ().
        """
        ...

    def paperSource(self) -> "QPrinter.PaperSource":
        """
        https://doc.qt.io/qt-6/qprinter.html#paperSource

        **QPrinter::PaperSource QPrinter::paperSource() const**

        Returns the printer's paper source. This is `Manual` or a printer tray
        or paper cassette.

        **See also** **setPaperSource** ().
        """
        ...

    def setPaperSource(self, a0: "QPrinter.PaperSource") -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setPaperSource

        **void QPrinter::setPaperSource(QPrinter::PaperSource source )**

        Sets the paper source setting to **source**.

        Windows only: This option can be changed while printing and will take
        effect from the next call to **newPage** ()

        **See also** **paperSource** ().
        """
        ...

    def supportsMultipleCopies(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprinter.html#supportsMultipleCopies

        **bool QPrinter::supportsMultipleCopies() const**

        Returns `true` if the printer supports printing multiple copies of the
        same document in one job; otherwise false is returned.

        On most systems this function will return true. However, on X11 systems
        that do not support CUPS, this function will return false. That means
        the application has to handle the number of copies by printing the same
        document the required number of times.

        **See also** **setCopyCount** () and **copyCount** ().
        """
        ...

    def copyCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qprinter.html#copyCount

        **int QPrinter::copyCount() const**

        Returns the number of copies that will be printed. The default value is
        1.

        **See also** **setCopyCount** () and **supportsMultipleCopies** ().
        """
        ...

    def setCopyCount(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setCopyCount

        **void QPrinter::setCopyCount(int count )**

        Sets the number of copies to be printed to **count**.

        The printer driver reads this setting and prints the specified number of
        copies.

        **See also** **copyCount** () and **supportsMultipleCopies** ().
        """
        ...

    def fullPage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprinter.html#fullPage

        **bool QPrinter::fullPage() const**

        Returns `true` if the origin of the printer's coordinate system is at
        the corner of the page and false if it is at the edge of the printable
        area.

        See **setFullPage** () for details and caveats.

        **See also** **setFullPage** () and **QPagedPaintDevice::pageLayout**
        ().
        """
        ...

    def setFullPage(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setFullPage

        **void QPrinter::setFullPage(bool fp )**

        If **fp** is true, enables support for painting over the entire page;
        otherwise restricts painting to the printable area reported by the
        device.

        By default, full page printing is disabled. In this case, the origin of
        the **QPrinter** 's coordinate system coincides with the top-left corner
        of the printable area.

        If full page printing is enabled, the origin of the **QPrinter** 's
        coordinate system coincides with the top-left corner of the paper
        itself. In this case, the **device metrics**  will report the exact same
        dimensions as indicated by {**QPageSize** }. It may not be possible to
        print on the entire physical page because of the printer's margins, so
        the application must account for the margins itself.

        **See also** **fullPage** (), **QPagedPaintDevice::pageLayout** (), and
        **QPagedPaintDevice::setPageSize** ().
        """
        ...

    def collateCopies(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprinter.html#collateCopies

        **bool QPrinter::collateCopies() const**

        Returns `true` if collation is turned on when multiple copies is
        selected. Returns `false` if it is turned off when multiple copies is
        selected. When collating is turned off the printing of each individual
        page will be repeated the numCopies() amount before the next page is
        started. With collating turned on all pages are printed before the next
        copy of those pages is started.

        **See also** **setCollateCopies** ().
        """
        ...

    def setCollateCopies(self, collate: bool) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setCollateCopies

        **void QPrinter::setCollateCopies(bool collate )**

        Sets the default value for collation checkbox when the print dialog
        appears. If **collate** is true, it will enable
        setCollateCopiesEnabled(). The default value is false. This value will
        be changed by what the user presses in the print dialog.

        **See also** **collateCopies** ().
        """
        ...

    def colorMode(self) -> "QPrinter.ColorMode":
        """
        https://doc.qt.io/qt-6/qprinter.html#colorMode

        **QPrinter::ColorMode QPrinter::colorMode() const**

        Returns the current color mode.

        **See also** **setColorMode** ().
        """
        ...

    def setColorMode(self, a0: "QPrinter.ColorMode") -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setColorMode

        **void QPrinter::setColorMode(QPrinter::ColorMode newColorMode )**

        Sets the printer's color mode to **newColorMode** , which can be either
        `Color` or `GrayScale`.

        **See also** **colorMode** ().
        """
        ...

    def resolution(self) -> int:
        """
        https://doc.qt.io/qt-6/qprinter.html#resolution

        **int QPrinter::resolution() const**

        Returns the current assumed resolution of the printer, as set by
        **setResolution** () or by the printer driver.

        **See also** **setResolution** ().
        """
        ...

    def setResolution(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setResolution

        **void QPrinter::setResolution(int dpi )**

        Requests that the printer prints at **dpi** or as near to **dpi** as
        possible.

        This setting affects the coordinate system as returned by, for example
        **QPainter::viewport** ().

        This function must be called before **QPainter::begin** () to have an
        effect on all platforms.

        **See also** **resolution** () and **QPagedPaintDevice::setPageSize**
        ().
        """
        ...

    def pageOrder(self) -> "QPrinter.PageOrder":
        """
        https://doc.qt.io/qt-6/qprinter.html#pageOrder

        **QPrinter::PageOrder QPrinter::pageOrder() const**

        Returns the current page order.

        The default page order is `FirstPageFirst`.

        **See also** **setPageOrder** ().
        """
        ...

    def setPageOrder(self, a0: "QPrinter.PageOrder") -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setPageOrder

        **void QPrinter::setPageOrder(QPrinter::PageOrder pageOrder )**

        Sets the page order to **pageOrder**.

        The page order can be **QPrinter::FirstPageFirst**  or
        **QPrinter::LastPageFirst** . The application is responsible for reading
        the page order and printing accordingly.

        This function is mostly useful for setting a default value that the user
        can override in the print dialog.

        This function is only supported under X11.

        **See also** **pageOrder** ().
        """
        ...

    def creator(self) -> str:
        """
        https://doc.qt.io/qt-6/qprinter.html#creator

        **QString QPrinter::creator() const**

        Returns the name of the application that created the document.

        **See also** **setCreator** ().
        """
        ...

    def setCreator(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setCreator

        **void QPrinter::setCreator(const QString & creator )**

        Sets the name of the application that created the document to
        **creator**.

        This function is only applicable to the X11 version of Qt. If no creator
        name is specified, the creator will be set to "Qt" followed by some
        version number.

        **See also** **creator** ().
        """
        ...

    def docName(self) -> str:
        """
        https://doc.qt.io/qt-6/qprinter.html#docName

        **QString QPrinter::docName() const**

        Returns the document name.

        **See also** **setDocName** () and
        **QPrintEngine::PrintEnginePropertyKey** .
        """
        ...

    def setDocName(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setDocName

        **void QPrinter::setDocName(const QString & name )**

        Sets the document name to **name**.

        On X11, the document name is for example used as the default output
        filename in **QPrintDialog** . Note that the document name does not
        affect the file name if the printer is printing to a file. Use the
        setOutputFile() function for this.

        **See also** **docName** () and **QPrintEngine::PrintEnginePropertyKey**
        .
        """
        ...

    def printProgram(self) -> str:
        """
        https://doc.qt.io/qt-6/qprinter.html#printProgram

        **QString QPrinter::printProgram() const**

        Returns the name of the program that sends the print output to the
        printer.

        The default is to return an empty string; meaning that **QPrinter**
        will try to be smart in a system-dependent way. On X11 only, you can set
        it to something different to use a specific print program. On the other
        platforms, this returns an empty string.

        **See also** **setPrintProgram** () and **setPrinterSelectionOption**
        ().
        """
        ...

    def setPrintProgram(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setPrintProgram

        **void QPrinter::setPrintProgram(const QString & printProg )**

        Sets the name of the program that should do the print job to
        **printProg**.

        On X11, this function sets the program to call with the PDF output. On
        other platforms, it has no effect.

        **See also** **printProgram** ().
        """
        ...

    def outputFileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qprinter.html#outputFileName

        **QString QPrinter::outputFileName() const**

        Returns the name of the output file. By default, this is an empty string
        (indicating that the printer shouldn't print to file).

        **See also** **setOutputFileName** () and
        **QPrintEngine::PrintEnginePropertyKey** .
        """
        ...

    def setOutputFileName(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setOutputFileName

        **void QPrinter::setOutputFileName(const QString & fileName )**

        Sets the name of the output file to **fileName**.

        Setting a null or empty name (0 or "") disables printing to a file.
        Setting a non-empty name enables printing to a file.

        This can change the value of **outputFormat** (). If the file name has
        the ".pdf" suffix PDF is generated. If the file name has a suffix other
        than ".pdf", the output format used is the one set with
        **setOutputFormat** ().

        **QPrinter**  uses Qt's cross-platform PDF print engines respectively.
        If you can produce this format natively, for example macOS can generate
        PDF's from its print engine, set the output format back to
        **NativeFormat** .

        **See also** **outputFileName** () and **setOutputFormat** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprinter.html#isValid

        **bool QPrinter::isValid() const**

        Returns `true` if the printer currently selected is a valid printer in
        the system, or a pure PDF printer; otherwise returns `false`.

        To detect other failures check the output of **QPainter::begin** () or
        **QPrinter::newPage** ().

        **QPrinter**  printer;
                printer.setOutputFormat(**QPrinter**
        ::PdfFormat);
        printer.setOutputFileName("/foobar/nonwritable.pdf");
        **QPainter**  painter;
                if (! painter.begin(&printer)) { //
        failed to open file
                    **qWarning** ("failed to open file, is
        it writable?");
                    return 1;
                }
        painter.drawText(10, 10, "Test");
                if (! printer.newPage()) {
        **qWarning** ("failed in flushing page to disk, disk full?");
        return 1;
                }
                painter.drawText(10, 10, "Test 2");
        painter.end();

        **See also** **setPrinterName** ().
        """
        ...

    def printerName(self) -> str:
        """
        https://doc.qt.io/qt-6/qprinter.html#printerName

        **QString QPrinter::printerName() const**

        Returns the printer name. This value is initially set to the name of the
        default printer.

        **See also** **setPrinterName** ().
        """
        ...

    def setPrinterName(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setPrinterName

        **void QPrinter::setPrinterName(const QString & name )**

        Sets the printer name to **name**.

        If the **name** is empty then the output format will be set to
        **PdfFormat** .

        If the **name** is not a valid printer then no change will be made.

        If the **name** is a valid printer then the output format will be set to
        **NativeFormat** .

        **See also** **printerName** (), **isValid** (), and **setOutputFormat**
        ().
        """
        ...

    def outputFormat(self) -> "QPrinter.OutputFormat":
        """
        https://doc.qt.io/qt-6/qprinter.html#outputFormat

        **QPrinter::OutputFormat QPrinter::outputFormat() const**

        Returns the output format for this printer.

        **See also** **setOutputFormat** ().
        """
        ...

    def setOutputFormat(self, format: "QPrinter.OutputFormat") -> None:
        """
        https://doc.qt.io/qt-6/qprinter.html#setOutputFormat

        **void QPrinter::setOutputFormat(QPrinter::OutputFormat format )**

        Sets the output format for this printer to **format**.

        If **format** is the same value as currently set then no change will be
        made.

        If **format** is **NativeFormat**  then the **printerName**  will be set
        to the default printer. If there are no valid printers configured then
        no change will be made. If you want to set **NativeFormat**  with a
        specific **printerName**  then use **setPrinterName** ().

        **See also** **outputFormat** () and **setPrinterName** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QTextCharFormat(QTextFormat):
    """
    https://doc.qt.io/qt-6/qtextcharformat.html

    **Detailed Description**

    The character format of text in a document specifies the visual properties
    of the text, as well as information about its role in a hypertext document.

    The font used can be set by supplying a font to the **setFont** () function,
    and each aspect of its appearance can be adjusted to give the desired
    effect. **setFontFamilies** () and **setFontPointSize** () define the font's
    family (e.g. Times) and printed size; **setFontWeight** () and
    **setFontItalic** () provide control over the style of the font.
    **setFontUnderline** (), **setFontOverline** (), **setFontStrikeOut** (),
    and **setFontFixedPitch** () provide additional effects for text.

    The color is set with **setForeground** (). If the text is intended to be
    used as an anchor (for hyperlinks), this can be enabled with **setAnchor**
    (). The **setAnchorHref** () and **setAnchorNames** () functions are used to
    specify the information about the hyperlink's destination and the anchor's
    name.

    **See also** **QTextFormat** , **QTextBlockFormat** , **QTextTableFormat** ,
    and **QTextListFormat** .
    """

    class FontPropertiesInheritanceBehavior(enum.Enum):
        FontPropertiesSpecifiedOnly: QTextCharFormat = ...
        FontPropertiesAll: QTextCharFormat = ...

    class UnderlineStyle(enum.Enum):
        NoUnderline: QTextCharFormat = ...
        SingleUnderline: QTextCharFormat = ...
        DashUnderline: QTextCharFormat = ...
        DotLine: QTextCharFormat = ...
        DashDotLine: QTextCharFormat = ...
        DashDotDotLine: QTextCharFormat = ...
        WaveUnderline: QTextCharFormat = ...
        SpellCheckUnderline: QTextCharFormat = ...

    class VerticalAlignment(enum.Enum):
        AlignNormal: QTextCharFormat = ...
        AlignSuperScript: QTextCharFormat = ...
        AlignSubScript: QTextCharFormat = ...
        AlignMiddle: QTextCharFormat = ...
        AlignTop: QTextCharFormat = ...
        AlignBottom: QTextCharFormat = ...
        AlignBaseline: QTextCharFormat = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#QTextCharFormat

        **QTextCharFormat::QTextCharFormat()**

        Constructs a new character format object.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QTextCharFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#QTextCharFormat

        **QTextCharFormat::QTextCharFormat()**

        Constructs a new character format object.
        """
        ...

    def baselineOffset(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#baselineOffset

        **[since 6.0] qreal QTextCharFormat::baselineOffset() const**

        Returns the the baseline offset in %.

        This function was introduced in Qt 6.0.

        **See also** **setBaselineOffset** (), **setSubScriptBaseline** (),
        **subScriptBaseline** (), **setSuperScriptBaseline** (), and
        **superScriptBaseline** ().
        """
        ...

    def setBaselineOffset(self, baseline: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setBaselineOffset

        **[since 6.0] void QTextCharFormat::setBaselineOffset(qreal baseline )**

        Sets the base line (in % of height) of text to **baseline**. A positive
        value moves the text up, by the corresponding %; a negative value moves
        it down. The default value is 0.

        This function was introduced in Qt 6.0.

        **See also** **baselineOffset** (), **setSubScriptBaseline** (),
        **subScriptBaseline** (), **setSuperScriptBaseline** (), and
        **superScriptBaseline** ().
        """
        ...

    def subScriptBaseline(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#subScriptBaseline

        **[since 6.0] qreal QTextCharFormat::subScriptBaseline() const**

        Returns the subscript's base line as a % of font height.

        This function was introduced in Qt 6.0.

        **See also** **setSubScriptBaseline** (), **setSuperScriptBaseline** (),
        **superScriptBaseline** (), **setBaselineOffset** (), and
        **baselineOffset** ().
        """
        ...

    def setSubScriptBaseline(self, baseline: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setSubScriptBaseline

        **[since 6.0] void QTextCharFormat::setSubScriptBaseline(qreal baseline
        )**

        Sets the subscript's base line as a % of font height to **baseline**.
        The default value is 16.67% (1/6 of height)

        This function was introduced in Qt 6.0.

        **See also** **subScriptBaseline** (), **setSuperScriptBaseline** (),
        **superScriptBaseline** (), **setBaselineOffset** (), and
        **baselineOffset** ().
        """
        ...

    def superScriptBaseline(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#superScriptBaseline

        **[since 6.0] qreal QTextCharFormat::superScriptBaseline() const**

        Returns the superscript's base line as a % of font height.

        This function was introduced in Qt 6.0.

        **See also** **setSuperScriptBaseline** (), **setSubScriptBaseline** (),
        **subScriptBaseline** (), **setBaselineOffset** (), and
        **baselineOffset** ().
        """
        ...

    def setSuperScriptBaseline(self, baseline: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setSuperScriptBaseline

        **[since 6.0] void QTextCharFormat::setSuperScriptBaseline(qreal
        baseline )**

        Sets the superscript's base line as a % of font height to **baseline**.
        The default value is 50% (1/2 of height).

        This function was introduced in Qt 6.0.

        **See also** **superScriptBaseline** (), **setSubScriptBaseline** (),
        **subScriptBaseline** (), **setBaselineOffset** (), and
        **baselineOffset** ().
        """
        ...

    def fontStyleName(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontStyleName

        **[since 5.13] QVariant QTextCharFormat::fontStyleName() const**

        Returns the text format's font style name.

        This function was introduced in Qt 5.13.

        **See also** **setFontStyleName** (), **font** (), and
        **QFont::styleName** ().
        """
        ...

    def setFontStyleName(self, styleName: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontStyleName

        **[since 5.13] void QTextCharFormat::setFontStyleName(const QString &
        styleName )**

        Sets the text format's font **styleName**.

        This function was introduced in Qt 5.13.

        **See also** **fontStyleName** (), **setFont** (), and
        **QFont::setStyleName** ().
        """
        ...

    def fontFamilies(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontFamilies

        **[since 5.13] QVariant QTextCharFormat::fontFamilies() const**

        Returns the text format's font families.

        This function was introduced in Qt 5.13.

        **See also** **setFontFamilies** () and **font** ().
        """
        ...

    def setFontFamilies(self, families: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontFamilies

        **[since 5.13] void QTextCharFormat::setFontFamilies(const QStringList &
        families )**

        Sets the text format's font **families**.

        This function was introduced in Qt 5.13.

        **See also** **fontFamilies** () and **setFont** ().
        """
        ...

    def fontLetterSpacingType(self) -> QFont.SpacingType:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontLetterSpacingType

        **[since 5.0] QFont::SpacingType
        QTextCharFormat::fontLetterSpacingType() const**

        Returns the letter spacing type of this format..

        This function was introduced in Qt 5.0.

        **See also** **setFontLetterSpacingType** (), **setFontLetterSpacing**
        (), and **fontLetterSpacing** ().
        """
        ...

    def setFontLetterSpacingType(self, letterSpacingType: QFont.SpacingType) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontLetterSpacingType

        **[since 5.0] void
        QTextCharFormat::setFontLetterSpacingType(QFont::SpacingType
        letterSpacingType )**

        Sets the letter spacing type of this format to **letterSpacingType**.

        This function was introduced in Qt 5.0.

        **See also** **fontLetterSpacingType** (), **setFontLetterSpacing** (),
        and **fontLetterSpacing** ().
        """
        ...

    def setFontStretch(self, factor: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontStretch

        **[since 5.0] void QTextCharFormat::setFontStretch(int factor )**

        Sets the stretch factor for the font to **factor**.

        The stretch factor changes the width of all characters in the font by
        factor percent. For example, setting **factor** to 150 results in all
        characters in the font being 1.5 times (ie. 150%) wider. The default
        stretch factor is 100. The minimum stretch factor is 1, and the maximum
        stretch factor is 4000.

        The stretch factor is only applied to outline fonts. The stretch factor
        is ignored for bitmap fonts.

        This function was introduced in Qt 5.0.

        **See also** **fontStretch** ().
        """
        ...

    def fontStretch(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontStretch

        **[since 5.0] int QTextCharFormat::fontStretch() const**

        Returns the current font stretching.

        This function was introduced in Qt 5.0.

        **See also** **setFontStretch** ().
        """
        ...

    def fontHintingPreference(self) -> QFont.HintingPreference:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontHintingPreference

        **QFont::HintingPreference QTextCharFormat::fontHintingPreference()
        const**

        Returns the hinting preference set for this text format.

        **See also** **setFontHintingPreference** (), **font** (), and
        **QFont::hintingPreference** ().
        """
        ...

    def setFontHintingPreference(
        self, hintingPreference: QFont.HintingPreference
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontHintingPreference

        **void
        QTextCharFormat::setFontHintingPreference(QFont::HintingPreference
        hintingPreference )**

        Sets the hinting preference of the text format's font to be
        **hintingPreference**.

        **See also** **fontHintingPreference** (), **setFont** (), and
        **QFont::setHintingPreference** ().
        """
        ...

    def fontKerning(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontKerning

        **bool QTextCharFormat::fontKerning() const**

        Returns `true` if the font kerning is enabled.

        **See also** **setFontKerning** () and **font** ().
        """
        ...

    def setFontKerning(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontKerning

        **void QTextCharFormat::setFontKerning(bool enable )**

        Enables kerning for this font if **enable** is true; otherwise disables
        it.

        When kerning is enabled, glyph metrics do not add up anymore, even for
        Latin text. In other words, the assumption that width('a') + width('b')
        is equal to width("ab") is not neccesairly true.

        **See also** **fontKerning** () and **setFont** ().
        """
        ...

    def fontStyleStrategy(self) -> QFont.StyleStrategy:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontStyleStrategy

        **QFont::StyleStrategy QTextCharFormat::fontStyleStrategy() const**

        Returns the current font style strategy.

        **See also** **setFontStyleStrategy** () and **font** ().
        """
        ...

    def fontStyleHint(self) -> QFont.StyleHint:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontStyleHint

        **QFont::StyleHint QTextCharFormat::fontStyleHint() const**

        Returns the font style hint.

        **See also** **setFontStyleHint** () and **font** ().
        """
        ...

    def setFontStyleStrategy(self, strategy: QFont.StyleStrategy) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontStyleStrategy

        **void QTextCharFormat::setFontStyleStrategy(QFont::StyleStrategy
        strategy )**

        Sets the font style **strategy**.

        **See also** **fontStyleStrategy** (), **setFont** (), and
        **QFont::setStyleStrategy** ().
        """
        ...

    def setFontStyleHint(
        self, hint: QFont.StyleHint, strategy: QFont.StyleStrategy = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontStyleHint

        **void QTextCharFormat::setFontStyleHint(QFont::StyleHint hint ,
        QFont::StyleStrategy strategy = QFont::PreferDefault)**

        Sets the font style **hint** and **strategy**.

        Qt does not support style hints on X11 since this information is not
        provided by the window system.

        **See also** **fontStyleHint** (), **setFont** (), and
        **QFont::setStyleHint** ().
        """
        ...

    def fontWordSpacing(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontWordSpacing

        **qreal QTextCharFormat::fontWordSpacing() const**

        Returns the current word spacing value.

        **See also** **setFontWordSpacing** ().
        """
        ...

    def setFontWordSpacing(self, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontWordSpacing

        **void QTextCharFormat::setFontWordSpacing(qreal spacing )**

        Sets the word spacing of this format to the given **spacing** , in
        pixels.

        **See also** **fontWordSpacing** ().
        """
        ...

    def fontLetterSpacing(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontLetterSpacing

        **qreal QTextCharFormat::fontLetterSpacing() const**

        Returns the current letter spacing.

        **See also** **setFontLetterSpacing** (), **setFontLetterSpacingType**
        (), and **fontLetterSpacingType** ().
        """
        ...

    def setFontLetterSpacing(self, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontLetterSpacing

        **void QTextCharFormat::setFontLetterSpacing(qreal spacing )**

        Sets the letter spacing of this format to the given **spacing**. The
        meaning of the value depends on the font letter spacing type.

        For percentage spacing a value of 100 indicates default spacing; a value
        of 200 doubles the amount of space a letter takes.

        **See also** **fontLetterSpacing** (), **setFontLetterSpacingType** (),
        and **fontLetterSpacingType** ().
        """
        ...

    def fontCapitalization(self) -> QFont.Capitalization:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontCapitalization

        **QFont::Capitalization QTextCharFormat::fontCapitalization() const**

        Returns the current capitalization type of the font.

        **See also** **setFontCapitalization** ().
        """
        ...

    def setFontCapitalization(self, capitalization: QFont.Capitalization) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontCapitalization

        **void QTextCharFormat::setFontCapitalization(QFont::Capitalization
        capitalization )**

        Sets the capitalization of the text that appears in this font to
        **capitalization**.

        A font's capitalization makes the text appear in the selected
        capitalization mode.

        **See also** **fontCapitalization** ().
        """
        ...

    def anchorNames(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#anchorNames

        **QStringList QTextCharFormat::anchorNames() const**

        Returns the anchor names associated with this text format, or an empty
        string list if none has been set. If the anchor names are set, text with
        this format can be the destination of a hypertext link.

        **See also** **setAnchorNames** ().
        """
        ...

    def setAnchorNames(self, names: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setAnchorNames

        **void QTextCharFormat::setAnchorNames(const QStringList & names )**

        Sets the text format's anchor **names**. For the anchor to work as a
        hyperlink, the destination must be set with **setAnchorHref** () and the
        anchor must be enabled with **setAnchor** ().

        **See also** **anchorNames** ().
        """
        ...

    def toolTip(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#toolTip

        **QString QTextCharFormat::toolTip() const**

        Returns the tool tip that is displayed for a fragment of text.

        **See also** **setToolTip** ().
        """
        ...

    def setToolTip(self, tip: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setToolTip

        **void QTextCharFormat::setToolTip(const QString & text )**

        Sets the tool tip for a fragment of text to the given **text**.

        **See also** **toolTip** ().
        """
        ...

    def underlineStyle(self) -> "QTextCharFormat.UnderlineStyle":
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#underlineStyle

        **QTextCharFormat::UnderlineStyle QTextCharFormat::underlineStyle()
        const**

        Returns the style of underlining the text.

        **See also** **setUnderlineStyle** ().
        """
        ...

    def setUnderlineStyle(self, style: "QTextCharFormat.UnderlineStyle") -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setUnderlineStyle

        **void
        QTextCharFormat::setUnderlineStyle(QTextCharFormat::UnderlineStyle style
        )**

        Sets the style of underlining the text to **style**.

        **See also** **underlineStyle** ().
        """
        ...

    def textOutline(self) -> QPen:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#textOutline

        **QPen QTextCharFormat::textOutline() const**

        Returns the pen used to draw the outlines of characters in this format.

        **See also** **setTextOutline** ().
        """
        ...

    def setTextOutline(
        self, pen: typing.Union[QPen, QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setTextOutline

        **void QTextCharFormat::setTextOutline(const QPen & pen )**

        Sets the pen used to draw the outlines of characters to the given
        **pen**.

        **See also** **textOutline** ().
        """
        ...

    def setTableCellColumnSpan(self, atableCellColumnSpan: int) -> None:
        ...

    def setTableCellRowSpan(self, atableCellRowSpan: int) -> None:
        ...

    def tableCellColumnSpan(self) -> int:
        ...

    def tableCellRowSpan(self) -> int:
        ...

    def anchorHref(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#anchorHref

        **QString QTextCharFormat::anchorHref() const**

        Returns the text format's hypertext link, or an empty string if none has
        been set.

        **See also** **setAnchorHref** ().
        """
        ...

    def setAnchorHref(self, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setAnchorHref

        **void QTextCharFormat::setAnchorHref(const QString & value )**

        Sets the hypertext link for the text format to the given **value**. This
        is typically a URL like "http://example.com/index.html".

        The anchor will be displayed with the **value** as its display text; if
        you want to display different text call **setAnchorNames** ().

        To format the text as a hypertext link use **setAnchor** ().

        **See also** **anchorHref** ().
        """
        ...

    def isAnchor(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#isAnchor

        **bool QTextCharFormat::isAnchor() const**

        Returns `true` if the text is formatted as an anchor; otherwise returns
        `false`.

        **See also** **setAnchor** (), **setAnchorHref** (), and
        **setAnchorNames** ().
        """
        ...

    def setAnchor(self, anchor: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setAnchor

        **void QTextCharFormat::setAnchor(bool anchor )**

        If **anchor** is true, text with this format represents an anchor, and
        is formatted in the appropriate way; otherwise the text is formatted
        normally. (Anchors are hyperlinks which are often shown underlined and
        in a different color from plain text.)

        The way the text is rendered is independent of whether or not the format
        has a valid anchor defined. Use **setAnchorHref** (), and optionally
        **setAnchorNames** () to create a hypertext link.

        **See also** **isAnchor** ().
        """
        ...

    def verticalAlignment(self) -> "QTextCharFormat.VerticalAlignment":
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#verticalAlignment

        **QTextCharFormat::VerticalAlignment
        QTextCharFormat::verticalAlignment() const**

        Returns the vertical alignment used for characters with this format.

        **See also** **setVerticalAlignment** ().
        """
        ...

    def setVerticalAlignment(
        self, alignment: "QTextCharFormat.VerticalAlignment"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setVerticalAlignment

        **void
        QTextCharFormat::setVerticalAlignment(QTextCharFormat::VerticalAlignment
        alignment )**

        Sets the vertical alignment used for the characters with this format to
        the **alignment** specified.

        **See also** **verticalAlignment** ().
        """
        ...

    def fontFixedPitch(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontFixedPitch

        **bool QTextCharFormat::fontFixedPitch() const**

        Returns `true` if the text format's font is fixed pitch; otherwise
        returns `false`.

        **See also** **setFontFixedPitch** () and **font** ().
        """
        ...

    def setFontFixedPitch(self, fixedPitch: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontFixedPitch

        **void QTextCharFormat::setFontFixedPitch(bool fixedPitch )**

        If **fixedPitch** is true, sets the text format's font to be fixed
        pitch; otherwise a non-fixed pitch font is used.

        **See also** **fontFixedPitch** () and **setFont** ().
        """
        ...

    def underlineColor(self) -> QColor:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#underlineColor

        **QColor QTextCharFormat::underlineColor() const**

        Returns the color used to draw underlines, overlines and strikeouts on
        the characters with this format.

        **See also** **setUnderlineColor** ().
        """
        ...

    def setUnderlineColor(
        self, color: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setUnderlineColor

        **void QTextCharFormat::setUnderlineColor(const QColor & color )**

        Sets the color used to draw underlines, overlines and strikeouts on the
        characters with this format to the **color** specified.

        **See also** **underlineColor** ().
        """
        ...

    def fontStrikeOut(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontStrikeOut

        **bool QTextCharFormat::fontStrikeOut() const**

        Returns `true` if the text format's font is struck out (has a horizontal
        line drawn through it); otherwise returns `false`.

        **See also** **setFontStrikeOut** () and **font** ().
        """
        ...

    def setFontStrikeOut(self, strikeOut: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontStrikeOut

        **void QTextCharFormat::setFontStrikeOut(bool strikeOut )**

        If **strikeOut** is true, sets the text format's font with strike-out
        enabled (with a horizontal line through it); otherwise it is displayed
        without strikeout.

        **See also** **fontStrikeOut** () and **setFont** ().
        """
        ...

    def fontOverline(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontOverline

        **bool QTextCharFormat::fontOverline() const**

        Returns `true` if the text format's font is overlined; otherwise returns
        `false`.

        **See also** **setFontOverline** () and **font** ().
        """
        ...

    def setFontOverline(self, overline: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontOverline

        **void QTextCharFormat::setFontOverline(bool overline )**

        If **overline** is true, sets the text format's font to be overlined;
        otherwise the font is displayed non-overlined.

        **See also** **fontOverline** () and **setFont** ().
        """
        ...

    def fontUnderline(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontUnderline

        **bool QTextCharFormat::fontUnderline() const**

        Returns `true` if the text format's font is underlined; otherwise
        returns `false`.

        **See also** **setFontUnderline** () and **font** ().
        """
        ...

    def setFontUnderline(self, underline: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontUnderline

        **void QTextCharFormat::setFontUnderline(bool underline )**

        If **underline** is true, sets the text format's font to be underlined;
        otherwise it is displayed non-underlined.

        **See also** **fontUnderline** () and **setFont** ().
        """
        ...

    def fontItalic(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontItalic

        **bool QTextCharFormat::fontItalic() const**

        Returns `true` if the text format's font is italic; otherwise returns
        `false`.

        **See also** **setFontItalic** () and **font** ().
        """
        ...

    def setFontItalic(self, italic: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontItalic

        **void QTextCharFormat::setFontItalic(bool italic )**

        If **italic** is true, sets the text format's font to be italic;
        otherwise the font will be non-italic.

        **See also** **fontItalic** () and **setFont** ().
        """
        ...

    def fontWeight(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontWeight

        **int QTextCharFormat::fontWeight() const**

        Returns the text format's font weight.

        **See also** **setFontWeight** (), **font** (), and **QFont::Weight** .
        """
        ...

    def setFontWeight(self, weight: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontWeight

        **void QTextCharFormat::setFontWeight(int weight )**

        Sets the text format's font weight to **weight**.

        **See also** **fontWeight** (), **setFont** (), and **QFont::Weight** .
        """
        ...

    def fontPointSize(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#fontPointSize

        **qreal QTextCharFormat::fontPointSize() const**

        Returns the font size used to display text in this format.

        **See also** **setFontPointSize** () and **font** ().
        """
        ...

    def setFontPointSize(self, size: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFontPointSize

        **void QTextCharFormat::setFontPointSize(qreal size )**

        Sets the text format's font **size**.

        **See also** **fontPointSize** () and **setFont** ().
        """
        ...

    def fontFamily(self) -> str:
        ...

    def setFontFamily(self, family: str) -> None:
        ...

    def font(self) -> QFont:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#font

        **QFont QTextCharFormat::font() const**

        Returns the font for this character format.

        **See also** **setFont** ().
        """
        ...

    def setFont(
        self,
        font: QFont,
        behavior: "QTextCharFormat.FontPropertiesInheritanceBehavior" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#setFont

        **[since 5.3] void QTextCharFormat::setFont(const QFont & font ,
        QTextCharFormat::FontPropertiesInheritanceBehavior behavior =
        FontPropertiesAll)**

        Sets the text format's **font**.

        If **behavior** is **QTextCharFormat::FontPropertiesAll** , the font
        property that has not been explicitly set is treated like as it were set
        with default value; If **behavior** is
        **QTextCharFormat::FontPropertiesSpecifiedOnly** , the font property
        that has not been explicitly set is ignored and the respective property
        value remains unchanged.

        This function was introduced in Qt 5.3.

        **See also** **font** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextcharformat.html#isValid

        **bool QTextCharFormat::isValid() const**

        Returns `true` if this character format is valid; otherwise returns
        false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QGestureRecognizer(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qgesturerecognizer.html

    **Detailed Description**

    Gesture recognizers are responsible for creating and managing **QGesture**
    objects and monitoring input events sent to **QWidget**  and
    **QGraphicsObject**  subclasses. QGestureRecognizer is the base class for
    implementing custom gestures.

    Developers that only need to provide gesture recognition for standard
    gestures do not need to use this class directly. Instances will be created
    behind the scenes by the framework.

    For an overview of gesture handling in Qt and information on using gestures
    in your applications, see the **Gestures in Widgets and Graphics View**
    document.

    **Recognizing Gestures**

    The process of recognizing gestures involves filtering input events sent to
    specific objects, and modifying the associated **QGesture**  objects to
    include relevant information about the user's input.

    Gestures are created when the framework calls **create** () to handle user
    input for a particular instance of a **QWidget**  or **QGraphicsObject**
    subclass. A **QGesture**  object is created for each widget or item that is
    configured to use gestures.

    Once a **QGesture**  has been created for a target object, the gesture
    recognizer will receive events for it in its **recognize** () handler
    function.

    When a gesture is canceled, the **reset** () function is called, giving the
    recognizer the chance to update the appropriate properties in the
    corresponding **QGesture**  object.

    **Supporting New Gestures**

    To add support for new gestures, you need to derive from QGestureRecognizer
    to create a custom recognizer class, construct an instance of this class,
    and register it with the application by calling
    **QGestureRecognizer::registerRecognizer** (). You can also subclass
    **QGesture**  to create a custom gesture class, or rely on dynamic
    properties to express specific details of the gesture you want to handle.

    Your custom QGestureRecognizer subclass needs to reimplement the
    **recognize** () function to handle and filter the incoming input events for
    **QWidget**  and **QGraphicsObject**  subclasses. Although the logic for
    gesture recognition is implemented in this function, you can store
    persistent information about the state of the recognition process in the
    **QGesture**  object supplied. The **recognize** () function must return a
    value of **QGestureRecognizer::Result**  that indicates the state of
    recognition for a given gesture and target object. This determines whether
    or not a gesture event will be delivered to a target object.

    If you choose to represent a gesture by a custom **QGesture**  subclass, you
    will need to reimplement the **create** () function to construct instances
    of your gesture class. Similarly, you may need to reimplement the **reset**
    () function if your custom gesture objects need to be specially handled when
    a gesture is canceled.

    **See also** **QGesture** .
    """

    class ResultFlag(enum.Flag):
        Ignore: QGestureRecognizer = ...
        MayBeGesture: QGestureRecognizer = ...
        TriggerGesture: QGestureRecognizer = ...
        FinishGesture: QGestureRecognizer = ...
        CancelGesture: QGestureRecognizer = ...
        ConsumeEventHint: QGestureRecognizer = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgesturerecognizer.html#QGestureRecognizer

        **QGestureRecognizer::QGestureRecognizer()**

        Constructs a new gesture recognizer object.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QGestureRecognizer") -> None:
        """
        https://doc.qt.io/qt-6/qgesturerecognizer.html#QGestureRecognizer

        **QGestureRecognizer::QGestureRecognizer()**

        Constructs a new gesture recognizer object.
        """
        ...

    @staticmethod
    def unregisterRecognizer(type: QtCore.Qt.GestureType) -> None:
        """
        https://doc.qt.io/qt-6/qgesturerecognizer.html#unregisterRecognizer

        **[static] void QGestureRecognizer::unregisterRecognizer(Qt::GestureType
        type )**

        Unregisters all gesture recognizers of the specified **type**.

        **See also** **registerRecognizer** ().
        """
        ...

    @staticmethod
    def registerRecognizer(recognizer: "QGestureRecognizer") -> QtCore.Qt.GestureType:
        """
        https://doc.qt.io/qt-6/qgesturerecognizer.html#registerRecognizer

        **[static] Qt::GestureType
        QGestureRecognizer::registerRecognizer(QGestureRecognizer * recognizer
        )**

        Registers the given **recognizer** in the gesture framework and returns
        a gesture ID for it.

        The application takes ownership of the **recognizer** and returns the
        gesture type ID associated with it. For gesture recognizers which handle
        custom **QGesture**  objects (i.e., those which return
        **Qt::CustomGesture**  in a **QGesture::gestureType** () function) the
        return value is a generated gesture ID with the **Qt::CustomGesture**
        flag set.

        **See also** **unregisterRecognizer** (), **QGestureRecognizer::create**
        (), and **QGesture** .
        """
        ...

    def reset(self, state: QGesture) -> None:
        """
        https://doc.qt.io/qt-6/qgesturerecognizer.html#reset

        **[virtual] void QGestureRecognizer::reset(QGesture * gesture )**

        This function is called by the framework to reset a given **gesture**.

        Reimplement this function to implement additional requirements for
        custom **QGesture**  objects. This may be necessary if you implement a
        custom **QGesture**  whose properties need special handling when the
        gesture is reset.
        """
        ...

    def recognize(
        self, state: QGesture, watched: QtCore.QObject, event: QtCore.QEvent
    ) -> "QGestureRecognizer.ResultFlag":
        """
        https://doc.qt.io/qt-6/qgesturerecognizer.html#recognize

        **[pure virtual] QGestureRecognizer::Result
        QGestureRecognizer::recognize(QGesture * gesture , QObject * watched ,
        QEvent * event )**

        Handles the given **event** for the **watched** object, updating the
        state of the **gesture** object as required, and returns a suitable
        result for the current recognition step.

        This function is called by the framework to allow the recognizer to
        filter input events dispatched to **QWidget**  or **QGraphicsObject**
        instances that it is monitoring.

        The result reflects how much of the gesture has been recognized. The
        state of the **gesture** object is set depending on the result.

        **See also** **QGestureRecognizer::Result** .
        """
        ...

    def create(self, target: QtCore.QObject) -> QGesture:
        """
        https://doc.qt.io/qt-6/qgesturerecognizer.html#create

        **[virtual] QGesture *QGestureRecognizer::create(QObject * target )**

        This function is called by Qt to create a new **QGesture**  object for
        the given **target** (**QWidget**  or **QGraphicsObject** ).

        Reimplement this function to create a custom **QGesture** -derived
        gesture object if necessary.

        The application takes ownership of the created gesture object.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QStyleOptionSlider(QStyleOptionComplex):
    """
    https://doc.qt.io/qt-6/qstyleoptionslider.html

    **Detailed Description**

    QStyleOptionSlider contains all the information that **QStyle**  functions
    need to draw **QSlider**  and **QScrollBar** .

    For performance reasons, there are few member functions and the access to
    the member variables is direct (i.e., using the `.` or `->` operator). This
    makes the structures straightforward to use and emphasizes that these are
    simply parameters used by the style functions.

    For an example demonstrating how style options can be used, see the
    **Styles**  example.

    **See also** **QStyleOptionComplex** , **QSlider** , and **QScrollBar** .
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleOptionSlider = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleOptionSlider = ...

    dialWrapping: bool = ...
    keyboardModifiers: QtCore = ...
    maximum: int = ...
    minimum: int = ...
    notchTarget: float = ...
    orientation: QtCore = ...
    pageStep: int = ...
    singleStep: int = ...
    sliderPosition: int = ...
    sliderValue: int = ...
    tickInterval: int = ...
    tickPosition: QSlider = ...
    upsideDown: bool = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionslider.html#QStyleOptionSlider

        **QStyleOptionSlider::QStyleOptionSlider()**

        Constructs a QStyleOptionSlider, initializing the members variables to
        their default values.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStyleOptionSlider") -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionslider.html#QStyleOptionSlider-1

        **QStyleOptionSlider::QStyleOptionSlider(const QStyleOptionSlider &
        other )**

        Constructs a copy of the **other** style option.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QStyleOptionGraphicsItem(QStyleOption):
    """
    https://doc.qt.io/qt-6/qstyleoptiongraphicsitem.html

    **Detailed Description**

    For performance reasons, there are few member functions and the access to
    the member variables is direct (i.e., using the `.` or `->` operator). This
    makes the structures straightforward to use and emphasizes that these are
    simply parameters used by the style functions.

    For an example demonstrating how style options can be used, see the
    **Styles**  example.

    **See also** **QStyleOption**  and **QGraphicsItem::paint** ().
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleOptionGraphicsItem = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleOptionGraphicsItem = ...

    exposedRect: QtCore = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptiongraphicsitem.html#QStyleOptionGraphic
        sItem

        **QStyleOptionGraphicsItem::QStyleOptionGraphicsItem()**

        Constructs a QStyleOptionGraphicsItem.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStyleOptionGraphicsItem") -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptiongraphicsitem.html#QStyleOptionGraphic
        sItem-1

        **QStyleOptionGraphicsItem::QStyleOptionGraphicsItem(const
        QStyleOptionGraphicsItem & other )**

        Constructs a copy of **other**.
        """
        ...

    @staticmethod
    def levelOfDetailFromTransform(worldTransform: QtGui.QTransform) -> float:
        """
        https://doc.qt.io/qt-6/qstyleoptiongraphicsitem.html#levelOfDetailFromTr
        ansform

        **[static] qreal
        QStyleOptionGraphicsItem::levelOfDetailFromTransform(const QTransform &
        worldTransform )**

        Returns the level of detail from the **worldTransform**.

        Its value represents the maximum value of the height and width of a
        unity rectangle, mapped using the **worldTransform** of the painter used
        to draw the item. By default, if no transformations are applied, its
        value is 1. If zoomed out 1:2, the level of detail will be 0.5, and if
        zoomed in 2:1, its value is 2.

        **See also** **QGraphicsScene::minimumRenderSize** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QHttpMultiPart(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qhttpmultipart.html

    **Detailed Description**

    The QHttpMultiPart resembles a MIME multipart message, as described in RFC
    2046, which is to be sent over HTTP. A multipart message consists of an
    arbitrary number of body parts (see **QHttpPart** ), which are separated by
    a unique boundary. The boundary of the QHttpMultiPart is constructed with
    the string "boundary_.oOo.**_** " followed by random characters, and
    provides enough uniqueness to make sure it does not occur inside the parts
    itself. If desired, the boundary can still be set via **setBoundary** ().

    As an example, consider the following code snippet, which constructs a
    multipart message containing a text part followed by an image part:

    **QHttpMultiPart**  *multiPart = new **QHttpMultiPart** (**QHttpMultiPart**
    ::FormDataType);

        **QHttpPart**  textPart;
    textPart.setHeader(**QNetworkRequest** ::ContentDispositionHeader,
    **QVariant** ("form-data; name=\\"text\\""));
        textPart.setBody("my text");
    **QHttpPart**  imagePart;
        imagePart.setHeader(**QNetworkRequest**
    ::ContentTypeHeader, **QVariant** ("image/jpeg"));
    imagePart.setHeader(**QNetworkRequest** ::ContentDispositionHeader,
    **QVariant** ("form-data; name=\\"image\\""));
        **QFile**  *file = new
    **QFile** ("image.jpg");
        file->open(**QIODevice** ::ReadOnly);
    imagePart.setBodyDevice(file);
        file->setParent(multiPart); // we cannot
    delete the file now, so delete it with the multiPart
    multiPart->append(textPart);
        multiPart->append(imagePart);
    **QUrl**  url("http://my.server.tld");
        **QNetworkRequest**
    request(url);

        **QNetworkAccessManager**  manager;
    **QNetworkReply**  *reply = manager.post(request, multiPart);
    multiPart->setParent(reply); // delete the multiPart with the reply
        //
    here connect signals etc.

    **See also** **QHttpPart**  and **QNetworkAccessManager::post** ().
    """

    class ContentType(enum.Enum):
        MixedType: QHttpMultiPart = ...
        RelatedType: QHttpMultiPart = ...
        FormDataType: QHttpMultiPart = ...
        AlternativeType: QHttpMultiPart = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qhttpmultipart.html#QHttpMultiPart

        **QHttpMultiPart::QHttpMultiPart(QObject * parent = nullptr)**

        Constructs a QHttpMultiPart with content type **MixedType**  and sets
        **parent** as the parent object.

        **See also** **QHttpMultiPart::ContentType** .
        """
        ...

    @typing.overload
    def __init__(
        self,
        contentType: "QHttpMultiPart.ContentType",
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhttpmultipart.html#QHttpMultiPart-1

        **QHttpMultiPart::QHttpMultiPart(QHttpMultiPart::ContentType contentType
        , QObject * parent = nullptr)**

        Constructs a QHttpMultiPart with content type **contentType** and sets
        parent as the parent object.

        **See also** **QHttpMultiPart::ContentType** .
        """
        ...

    def setBoundary(self, boundary: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qhttpmultipart.html#setBoundary

        **void QHttpMultiPart::setBoundary(const QByteArray & boundary )**

        Sets the boundary to **boundary**.

        Usually, you do not need to generate a boundary yourself; upon
        construction the boundary is initiated with the string
        "boundary_.oOo.**_** " followed by random characters, and provides
        enough uniqueness to make sure it does not occur inside the parts
        itself.

        **See also** **boundary** ().
        """
        ...

    def boundary(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qhttpmultipart.html#boundary

        **QByteArray QHttpMultiPart::boundary() const**

        returns the boundary.

        **See also** **setBoundary** ().
        """
        ...

    def setContentType(self, contentType: "QHttpMultiPart.ContentType") -> None:
        """
        https://doc.qt.io/qt-6/qhttpmultipart.html#setContentType

        **void QHttpMultiPart::setContentType(QHttpMultiPart::ContentType
        contentType )**

        Sets the content type to **contentType**. The content type will be used
        in the HTTP header section when sending the multipart message via
        **QNetworkAccessManager::post** (). In case you want to use a multipart
        subtype not contained in **QHttpMultiPart::ContentType** , you can add
        the "Content-Type" header field to the **QNetworkRequest**  by hand, and
        then use this request together with the multipart message for posting.

        **See also** **QHttpMultiPart::ContentType**  and
        **QNetworkAccessManager::post** ().
        """
        ...

    def append(self, httpPart: QHttpPart) -> None:
        """
        https://doc.qt.io/qt-6/qhttpmultipart.html#append

        **void QHttpMultiPart::append(const QHttpPart & httpPart )**

        Appends **httpPart** to this multipart.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QWriteLocker(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qwritelocker.html

    **Detailed Description**

    The purpose of QWriteLocker (and **QReadLocker** ) is to simplify
    **QReadWriteLock**  locking and unlocking. Locking and unlocking statements
    or in exception handling code is error-prone and difficult to debug.
    QWriteLocker can be used in such situations to ensure that the state of the
    lock is always well-defined.

    Here's an example that uses QWriteLocker to lock and unlock a read-write
    lock for writing:

    **QReadWriteLock**  lock;

        void writeData(const **QByteArray**
    &data)
        {
            **QWriteLocker**  locker(&lock);
            ...
        }

    It is equivalent to the following code:

    **QReadWriteLock**  lock;

        void writeData(const **QByteArray**
    &data)
        {
            lock.lockForWrite();
            ...
            lock.unlock();
    }

    The **QMutexLocker**  documentation shows examples where the use of a locker
    object greatly simplifies programming.

    **See also** **QReadLocker**  and **QReadWriteLock** .
    """

    def __init__(self, areadWriteLock: QReadWriteLock) -> None:
        """
        https://doc.qt.io/qt-6/qwritelocker.html#QWriteLocker

        **QWriteLocker::QWriteLocker(QReadWriteLock * lock )**

        Constructs a QWriteLocker and locks **lock** for writing. The lock will
        be unlocked when the QWriteLocker is destroyed. If `lock` is zero,
        QWriteLocker does nothing.

        **See also** **QReadWriteLock::lockForWrite** ().
        """
        ...

    def __exit__(
        self, type: typing.Any, value: typing.Any, traceback: typing.Any
    ) -> None:
        ...

    def __enter__(self) -> typing.Any:
        ...

    def readWriteLock(self) -> QReadWriteLock:
        """
        https://doc.qt.io/qt-6/qwritelocker.html#readWriteLock

        **QReadWriteLock *QWriteLocker::readWriteLock() const**

        Returns a pointer to the read-write lock that was passed to the
        constructor.
        """
        ...

    def relock(self) -> None:
        """
        https://doc.qt.io/qt-6/qwritelocker.html#relock

        **void QWriteLocker::relock()**

        Relocks an unlocked lock.

        **See also** **unlock** ().
        """
        ...

    def unlock(self) -> None:
        """
        https://doc.qt.io/qt-6/qwritelocker.html#unlock

        **void QWriteLocker::unlock()**

        Unlocks the lock associated with this locker.

        **See also** **QReadWriteLock::unlock** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QColorTransform(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcolortransform.html

    **Detailed Description**

    QColorTransform is an instantiation of a transformation between color
    spaces. It can be applied on color and pixels to convert them from one color
    space to another.

    Setting up a QColorTransform takes some preprocessing, so keeping around
    QColorTransforms that you need often is recommended, instead of generating
    them on the fly.
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, colorTransform: "QColorTransform") -> None:
        ...

    @typing.overload
    def map(self, argb: int) -> int:
        """
        https://doc.qt.io/qt-6/qcolortransform.html#map

        **QRgb QColorTransform::map(QRgb argb ) const**

        Applies the color transformation on the **QRgb**  value **argb**.

        The input should be opaque or unpremultiplied.
        """
        ...

    @typing.overload
    def map(self, rgba64: "QRgba64") -> "QRgba64":
        """
        https://doc.qt.io/qt-6/qcolortransform.html#map-1

        **QRgba64 QColorTransform::map(QRgba64 rgba64 ) const**

        Applies the color transformation on the **QRgba64**  value **rgba64**.

        The input should be opaque or unpremultiplied.
        """
        ...

    @typing.overload
    def map(
        self, color: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> QColor:
        """
        https://doc.qt.io/qt-6/qcolortransform.html#map-2

        **QColor QColorTransform::map(const QColor & color ) const**

        Applies the color transformation on the **QColor**  value **color**.
        """
        ...

    def swap(self, other: "QColorTransform") -> None:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6.QtPrintSupport import *


class QPrintDialog(QAbstractPrintDialog):
    """
    https://doc.qt.io/qt-6/qprintdialog.html

    **Detailed Description**

    The dialog allows users to change document-related settings, such as the
    paper size and orientation, type of print (color or grayscale), range of
    pages, and number of copies to print.

    Controls are also provided to enable users to choose from the printers
    available, including any configured network printers.

    Typically, QPrintDialog objects are constructed with a **QPrinter**  object,
    and executed using the **exec** () function.

    **QPrintDialog**  printDialog(printer, parent);
        if (printDialog.exec()
    == **QDialog** ::Accepted) {
            // print ...
        }

    If the dialog is accepted by the user, the **QPrinter**  object is correctly
    configured for printing.

    ![](images/plastique-printdialog.png)![](images/plastique-printdialog-
    properties.png)

    The printer dialog (shown above in Plastique style) enables access to common
    printing properties. On X11 platforms that use the CUPS printing system, the
    settings for each available printer can be modified via the dialog's
    **Properties** push button.

    On Windows and macOS, the native print dialog is used, which means that some
    **QWidget**  and **QDialog**  properties set on the dialog won't be
    respected. The native print dialog on macOS does not support setting printer
    options, i.e. **setOptions** () and **setOption** () have no effect.

    In Qt 4.4, it was possible to use the static functions to show a sheet on
    macOS. This is no longer supported in Qt 4.5. If you want this
    functionality, use **QPrintDialog::open** ().

    **See also** **QPageSetupDialog**  and **QPrinter** .
    """

    @typing.overload
    def __init__(
        self, printer: "QPrinter", parent: typing.Optional[QtWidgets.QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprintdialog.html#QPrintDialog

        **QPrintDialog::QPrintDialog(QPrinter * printer , QWidget * parent =
        nullptr)**

        Constructs a new modal printer dialog for the given **printer** with the
        given **parent**.
        """
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtWidgets.QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qprintdialog.html#QPrintDialog-1

        **QPrintDialog::QPrintDialog(QWidget * parent = nullptr)**

        Constructs a print dialog with the given **parent**.
        """
        ...

    @typing.overload
    def open(self) -> None:
        """
        https://doc.qt.io/qt-6/qprintdialog.html#open

        **void QPrintDialog::open(QObject * receiver , const char * member )**

        This is an overloaded function.

        Opens the dialog and connects its **accepted** () signal to the slot
        specified by **receiver** and **member**.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    @typing.overload
    def open(self, slot: PYQT_SLOT) -> None:
        """
        https://doc.qt.io/qt-6/qprintdialog.html#open

        **void QPrintDialog::open(QObject * receiver , const char * member )**

        This is an overloaded function.

        Opens the dialog and connects its **accepted** () signal to the slot
        specified by **receiver** and **member**.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qprintdialog.html#setVisible

        **[override virtual] void QPrintDialog::setVisible(bool visible )**

        Reimplements: **QDialog::setVisible** (bool visible).
        """
        ...

    def options(self) -> QAbstractPrintDialog.PrintDialogOption:
        """
        https://doc.qt.io/qt-6/qprintdialog.html#options-prop

        **options : PrintDialogOptions**

        This property holds the various options that affect the look and feel of
        the dialog

        By default, all options are disabled.

        Options should be set before showing the dialog. Setting them while the
        dialog is visible is not guaranteed to have an immediate effect on the
        dialog (depending on the option and on the platform).

        **Access functions:**

        QAbstractPrintDialog::PrintDialogOptions **options** () const
        void
        **setOptions** (QAbstractPrintDialog::PrintDialogOptions **options** )

        **See also** **setOption** () and **testOption** ().

        **Member Function Documentation**
        """
        ...

    def setOptions(self, options: QAbstractPrintDialog.PrintDialogOption) -> None:
        """
        https://doc.qt.io/qt-6/qprintdialog.html#options-prop

        **options : PrintDialogOptions**

        This property holds the various options that affect the look and feel of
        the dialog

        By default, all options are disabled.

        Options should be set before showing the dialog. Setting them while the
        dialog is visible is not guaranteed to have an immediate effect on the
        dialog (depending on the option and on the platform).

        **Access functions:**

        QAbstractPrintDialog::PrintDialogOptions **options** () const
        void
        **setOptions** (QAbstractPrintDialog::PrintDialogOptions **options** )

        **See also** **setOption** () and **testOption** ().

        **Member Function Documentation**
        """
        ...

    def testOption(self, option: QAbstractPrintDialog.PrintDialogOption) -> bool:
        """
        https://doc.qt.io/qt-6/qprintdialog.html#testOption

        **bool QPrintDialog::testOption(QAbstractPrintDialog::PrintDialogOption
        option ) const**

        Returns `true` if the given **option** is enabled; otherwise, returns
        false.

        **See also** **options**  and **setOption** ().
        """
        ...

    def setOption(
        self, option: QAbstractPrintDialog.PrintDialogOption, on: bool = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprintdialog.html#setOption

        **void QPrintDialog::setOption(QAbstractPrintDialog::PrintDialogOption
        option , bool on = true)**

        Sets the given **option** to be enabled if **on** is true; otherwise,
        clears the given **option**.

        **See also** **options**  and **testOption** ().
        """
        ...

    def done(self, result: int) -> None:
        """
        https://doc.qt.io/qt-6/qprintdialog.html#done

        **[override virtual] void QPrintDialog::done(int result )**

        Reimplements: **QDialog::done** (int r).

        Closes the dialog and sets its result code to **result**. If this dialog
        is shown with **exec** (), done() causes the local event loop to finish,
        and **exec** () to return **result**.

        **Note:** This function does not apply to the Native Print Dialog on the
        Mac macOS and Windows platforms, because the dialog is required to be
        modal and only the user can close it.

        **See also** **QDialog::done** ().
        """
        ...

    def exec(self) -> int:
        """
        https://doc.qt.io/qt-6/qprintdialog.html#exec

        **[override virtual] int QPrintDialog::exec()**

        Reimplements: **QDialog::exec** ().
        """
        ...

    @property
    def accepted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qprintdialog.html#accepted

        **[signal] void QPrintDialog::accepted(QPrinter * printer )**

        This signal is emitted when the user accepts the values set in the print
        dialog. The **printer** parameter includes the printer that the settings
        were applied to.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QColor(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcolor.html

    **Detailed Description**

    A color is normally specified in terms of RGB (red, green, and blue)
    components, but it is also possible to specify it in terms of HSV (hue,
    saturation, and value) and CMYK (cyan, magenta, yellow and black)
    components. In addition a color can be specified using a color name. The
    color name can be any of the SVG 1.0 color names.

    RGBHSVCMYK
    ![](images/qcolor-rgb.png)![](images/qcolor-
    hsv.png)![](images/qcolor-cmyk.png)

    The QColor constructor creates the color based on RGB values. To create a
    QColor based on either HSV or CMYK values, use the **toHsv** () and
    **toCmyk** () functions respectively. These functions return a copy of the
    color using the desired format. In addition the static **fromRgb** (),
    **fromHsv** () and **fromCmyk** () functions create colors from the
    specified values. Alternatively, a color can be converted to any of the
    three formats using the **convertTo** () function (returning a copy of the
    color in the desired format), or any of the **setRgb** (), **setHsv** () and
    **setCmyk** () functions altering **this** color's format. The **spec** ()
    function tells how the color was specified.

    A color can be set by passing an RGB string (such as "#112233"), or an ARGB
    string (such as "#ff112233") or a color name (such as "blue"), to the
    **setNamedColor** () function. The color names are taken from the SVG 1.0
    color names. The **name** () function returns the name of the color in the
    format "#RRGGBB". Colors can also be set using **setRgb** (), **setHsv** ()
    and **setCmyk** (). To get a lighter or darker color use the **lighter** ()
    and **darker** () functions respectively.

    The **isValid** () function indicates whether a QColor is legal at all. For
    example, a RGB color with RGB values out of range is illegal. For
    performance reasons, QColor mostly disregards illegal colors, and for that
    reason, the result of using an invalid color is undefined.

    The color components can be retrieved individually, e.g with **red** (),
    **hue** () and **cyan** (). The values of the color components can also be
    retrieved in one go using the **getRgb** (), **getHsv** () and **getCmyk**
    () functions. Using the RGB color model, the color components can in
    addition be accessed with **rgb** ().

    There are several related non-members: **QRgb**  is a typdef for an unsigned
    int representing the RGB value triplet (r, g, b). Note that it also can hold
    a value for the alpha-channel (for more information, see the **Alpha-Blended
    Drawing**  section). The **qRed** (), **qBlue** () and **qGreen** ()
    functions return the respective component of the given **QRgb**  value,
    while the **qRgb** () and **qRgba** () functions create and return the
    **QRgb**  triplet based on the given component values. Finally, the
    **qAlpha** () function returns the alpha component of the provided **QRgb**
    , and the **qGray** () function calculates and return a gray value based on
    the given value.

    QColor is platform and device independent. The **QColormap**  class maps the
    color to the hardware.

    For more information about painting in general, see the **Paint System**
    documentation.

    **Integer vs. Floating Point Precision**

    QColor supports floating point precision and provides floating point
    versions of all the color components functions, e.g. **getRgbF** (),
    **hueF** () and **fromCmykF** (). Note that since the components are stored
    using 16-bit integers, there might be minor deviations between the values
    set using, for example, **setRgbF** () and the values returned by the
    **getRgbF** () function due to rounding.

    While the integer based functions take values in the range 0-255 (except
    **hue** () which must have values within the range 0-359), the floating
    point functions accept values in the range 0.0 - 1.0.

    **Alpha-Blended Drawing**

    QColor also support alpha-blended outlining and filling. The alpha channel
    of a color specifies the transparency effect, 0 represents a fully
    transparent color, while 255 represents a fully opaque color. For example:

    // Specify semi-transparent red
        painter.setBrush(**QColor** (255, 0, 0,
    127));
        painter.drawRect(0, 0, width() / 2, height());

        //
    Specify semi-transparent blue
        painter.setBrush(**QColor** (0, 0, 255,
    127));
        painter.drawRect(0, 0, width(), height() / 2);

    The code above produces the following output:

    ![](images/alphafill.png)

    The alpha channel of a color can be retrieved and set using the **alpha** ()
    and **setAlpha** () functions if its value is an integer, and **alphaF** ()
    and **setAlphaF** () if its value is float. By default, the alpha-channel is
    set to 255 (opaque). To retrieve and set **all** the RGB color components
    (including the alpha-channel) in one go, use the **rgba** () and **setRgba**
    () functions.

    **Predefined Colors**

    There are 20 predefined QColor objects in the `QColorConstants` namespace,
    including black, white, primary and secondary colors, darker versions of
    these colors, and three shades of gray. Furthermore, the
    `QColorConstants::Svg` namespace defines QColor objects for the standard
    **SVG color keyword names** .

    ![Qt Colors](images/qt-colors.png)

    The `QColorConstants::Color0`, `QColorConstants::Color1` and
    `QColorConstants::Transparent` colors are used for special purposes.

    `QColorConstants::Color0` (zero pixel value) and `QColorConstants::Color1`
    (non-zero pixel value) are special colors for drawing in QBitmaps. Painting
    with `QColorConstants::Color0` sets the bitmap bits to 0 (transparent; i.e.,
    background), and painting with c{QColorConstants::Color1} sets the bits to 1
    (opaque; i.e., foreground).

    `QColorConstants::Transparent` is used to indicate a transparent pixel. When
    painting with this value, a pixel value will be used that is appropriate for
    the underlying pixel format in use.

    For historical reasons, the 20 predefined colors are also available in the
    **Qt::GlobalColor**  enumeration.

    Finally, QColor recognizes a variety of color names (as strings); the static
    **colorNames** () function returns a **QStringList**  color names that
    QColor knows about.

    **The Extended RGB Color Model**

    The extended RGB color model, also known as the scRGB color space, is the
    same the RGB color model except it allows values under 0.0, and over 1.0.
    This makes it possible to represent colors that would otherwise be outside
    the range of the RGB colorspace but still use the same values for colors
    inside the RGB colorspace.

    **The HSV Color Model**

    The RGB model is hardware-oriented. Its representation is close to what most
    monitors show. In contrast, HSV represents color in a way more suited to the
    human perception of color. For example, the relationships "stronger than",
    "darker than", and "the opposite of" are easily expressed in HSV but are
    much harder to express in RGB.

    HSV, like RGB, has three components:

    * H, for hue, is in the range 0 to 359 if the color is chromatic (not gray),
    or meaningless if it is gray. It represents degrees on the color wheel
    familiar to most people. Red is 0 (degrees), green is 120, and blue is 240.
    ![](images/qcolor-hue.png)

      * S, for saturation, is in the range 0 to 255,
    and the bigger it is, the stronger the color is. Grayish colors have
    saturation near 0; very strong colors have saturation near 255.
    ![](images/qcolor-saturation.png)

      * V, for value, is in the range 0 to
    255 and represents lightness or brightness of the color. 0 is black; 255 is
    as far from black as possible.

    ![](images/qcolor-value.png)

    Here are some examples: pure red is H=0, S=255, V=255; a dark red, moving
    slightly towards the magenta, could be H=350 (equivalent to -10), S=255,
    V=180; a grayish light red could have H about 0 (say 350-359 or 0-10), S
    about 50-100, and S=255.

    Qt returns a hue value of -1 for achromatic colors. If you pass a hue value
    that is too large, Qt forces it into range. Hue 360 or 720 is treated as 0;
    hue 540 is treated as 180.

    In addition to the standard HSV model, Qt provides an alpha-channel to
    feature **alpha-blended drawing** .

    **The HSL Color Model**

    HSL is similar to HSV, however instead of the Value parameter, HSL specifies
    a Lightness parameter which maps somewhat differently to the brightness of
    the color.

    Similarly, the HSL saturation value is not in general the same as the HSV
    saturation value for the same color. **hslSaturation** () provides the
    color's HSL saturation value, while **saturation** () and **hsvSaturation**
    () provides the HSV saturation value.

    The hue value is defined to be the same in HSL and HSV.

    **The CMYK Color Model**

    While the RGB and HSV color models are used for display on computer
    monitors, the CMYK model is used in the four-color printing process of
    printing presses and some hard-copy devices.

    CMYK has four components, all in the range 0-255: cyan (C), magenta (M),
    yellow (Y) and black (K). Cyan, magenta and yellow are called subtractive
    colors; the CMYK color model creates color by starting with a white surface
    and then subtracting color by applying the appropriate components. While
    combining cyan, magenta and yellow gives the color black, subtracting one or
    more will yield any other color. When combined in various percentages, these
    three colors can create the entire spectrum of colors.

    Mixing 100 percent of cyan, magenta and yellow **does** produce black, but
    the result is unsatisfactory since it wastes ink, increases drying time, and
    gives a muddy colour when printing. For that reason, black is added in
    professional printing to provide a solid black tone; hence the term 'four
    color process'.

    In addition to the standard CMYK model, Qt provides an alpha-channel to
    feature **alpha-blended drawing** .

    **See also** **QPalette** , **QBrush** , and **QColorConstants** .
    """

    class NameFormat(enum.Enum):
        HexRgb: QColor = ...
        HexArgb: QColor = ...

    class Spec(enum.Enum):
        Invalid: QColor = ...
        Rgb: QColor = ...
        Hsv: QColor = ...
        Cmyk: QColor = ...
        Hsl: QColor = ...
        ExtendedRgb: QColor = ...

    @typing.overload
    def __init__(self, color: QtCore.Qt.GlobalColor) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#QColor

        **QColor::QColor()**

        Constructs an invalid color with the RGB value (0, 0, 0). An invalid
        color is a color that is not properly set up for the underlying window
        system.

        The alpha value of an invalid color is unspecified.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, rgb: int) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#QColor-1

        **QColor::QColor(Qt::GlobalColor color )**

        This is an overloaded function.

        Constructs a new color with a color value of **color**.

        **See also** **isValid** () and **Predefined Colors** .
        """
        ...

    @typing.overload
    def __init__(self, rgba64: "QRgba64") -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#QColor-2

        **QColor::QColor(int r , int g , int b , int a = 255)**

        Constructs a color with the RGB value **r** , **g** , **b** , and the
        alpha-channel (transparency) value of **a**.

        The color is left invalid if any of the arguments are invalid.

        **See also** **setRgba** () and **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#QColor-3

        **QColor::QColor(QRgb color )**

        Constructs a color with the value **color**. The alpha component is
        ignored and set to solid.

        **See also** **fromRgb** () and **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#QColor-4

        **[since 5.6] QColor::QColor(QRgba64 rgba64 )**

        Constructs a color with the value **rgba64**.

        This function was introduced in Qt 5.6.

        **See also** **fromRgba64** ().
        """
        ...

    @typing.overload
    def __init__(self, r: int, g: int, b: int, alpha: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#QColor-5

        **QColor::QColor(const QString & name )**

        Constructs a named color in the same way as **setNamedColor** () using
        the given **name**.

        The color is left invalid if the **name** cannot be parsed.

        **See also** **setNamedColor** (), **name** (), and **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#QColor-7

        **QColor::QColor(const char * name )**

        Constructs a named color in the same way as **setNamedColor** () using
        the given **name**.

        This is an overloaded function.

        **See also** **setNamedColor** (), **name** (), and **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QColor") -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#QColor-8

        **[since 5.8] QColor::QColor(QLatin1String name )**

        Constructs a named color in the same way as **setNamedColor** () using
        the given **name**.

        This is an overloaded function.

        This function was introduced in Qt 5.8.

        **See also** **setNamedColor** (), **name** (), and **isValid** ().
        """
        ...

    def toExtendedRgb(self) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#toExtendedRgb

        **[since 5.14] QColor QColor::toExtendedRgb() const**

        Create and returns an extended RGB **QColor**  based on this color.

        This function was introduced in Qt 5.14.

        **See also** **toRgb**  and **convertTo** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromRgba64(r: int, g: int, b: int, alpha: int = ...) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#fromRgba64

        **[static, since 5.6] QColor QColor::fromRgba64(ushort r , ushort g ,
        ushort b , ushort a = USHRT_MAX)**

        Static convenience function that returns a **QColor**  constructed from
        the RGBA64 color values, **r** (red), **g** (green), **b** (blue), and
        **a** (alpha-channel, i.e. transparency).

        This function was introduced in Qt 5.6.

        **See also** **fromRgb** (), **fromRgbF** (), **toRgb** (), and
        **isValid** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromRgba64(rgba: "QRgba64") -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#fromRgba64-1

        **[static, since 5.6] QColor QColor::fromRgba64(QRgba64 rgba64 )**

        Static convenience function that returns a **QColor**  constructed from
        the given **QRgba64**  value **rgba64**.

        This function was introduced in Qt 5.6.

        **See also** **fromRgb** (), **fromRgbF** (), **toRgb** (), and
        **isValid** ().
        """
        ...

    def setRgba64(self, rgba: "QRgba64") -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setRgba64

        **[since 5.6] void QColor::setRgba64(QRgba64 rgba )**

        Sets the RGB64 value to **rgba** , including its alpha.

        This function was introduced in Qt 5.6.

        **See also** **setRgba** () and **rgba64** ().
        """
        ...

    def rgba64(self) -> "QRgba64":
        """
        https://doc.qt.io/qt-6/qcolor.html#rgba64

        **[since 5.6] QRgba64 QColor::rgba64() const**

        Returns the RGB64 value of the color, including its alpha.

        For an invalid color, the alpha value of the returned color is
        unspecified.

        This function was introduced in Qt 5.6.

        **See also** **setRgba64** (), **rgba** (), and **rgb** ().
        """
        ...

    @staticmethod
    def isValidColor(name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qcolor.html#isValidColor

        **[static] bool QColor::isValidColor(const QString & name )**

        Returns `true` if the **name** is a valid color name and can be used to
        construct a valid **QColor**  object, otherwise returns false.

        It uses the same algorithm used in **setNamedColor** ().

        **See also** **setNamedColor** ().
        """
        ...

    @staticmethod
    def fromHslF(h: float, s: float, l: float, alpha: float = ...) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#fromHslF

        **[static] QColor QColor::fromHslF(float h , float s , float l , float a
        = 1.0)**

        This is an overloaded function.

        Static convenience function that returns a **QColor**  constructed from
        the HSV color values, **h** (hue), **s** (saturation), **l**
        (lightness), and **a** (alpha-channel, i.e. transparency).

        All the values must be in the range 0.0-1.0.

        **See also** **toHsl** (), **fromHsl** (), **isValid** (), and **The HSL
        Color Model** .
        """
        ...

    @staticmethod
    def fromHsl(h: int, s: int, l: int, alpha: int = ...) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#fromHsl

        **[static] QColor QColor::fromHsl(int h , int s , int l , int a = 255)**

        Static convenience function that returns a **QColor**  constructed from
        the HSV color values, **h** (hue), **s** (saturation), **l**
        (lightness), and **a** (alpha-channel, i.e. transparency).

        The value of **s** , **l** , and **a** must all be in the range 0-255;
        the value of **h** must be in the range 0-359.

        **See also** **toHsl** (), **fromHslF** (), **isValid** (), and **The
        HSL Color Model** .
        """
        ...

    def toHsl(self) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#toHsl

        **QColor QColor::toHsl() const**

        Creates and returns an HSL **QColor**  based on this color.

        **See also** **fromHsl** (), **convertTo** (), **isValid** (), and **The
        HSL Color Model** .
        """
        ...

    def setHslF(self, h: float, s: float, l: float, alpha: float = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setHslF

        **void QColor::setHslF(float h , float s , float l , float a = 1.0)**

        Sets a HSL color lightness; **h** is the hue, **s** is the saturation,
        **l** is the lightness and **a** is the alpha component of the HSL
        color.

        All the values must be in the range 0.0-1.0.

        **See also** **getHslF** () and **setHsl** ().
        """
        ...

    def getHslF(self) -> typing.Tuple[float, float, float, float]:
        """
        https://doc.qt.io/qt-6/qcolor.html#getHslF

        **void QColor::getHslF(float * h , float * s , float * l , float * a =
        nullptr) const**

        Sets the contents pointed to by **h** , **s** , **l** , and **a** , to
        the hue, saturation, lightness, and alpha-channel (transparency)
        components of the color's HSL value.

        These components can be retrieved individually using the **hslHueF** (),
        **hslSaturationF** (), **lightnessF** () and **alphaF** () functions.

        **See also** **getHsl** (), **setHslF** (), and **The HSL Color Model**
        .
        """
        ...

    def setHsl(self, h: int, s: int, l: int, alpha: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setHsl

        **void QColor::setHsl(int h , int s , int l , int a = 255)**

        Sets a HSL color value; **h** is the hue, **s** is the saturation, **l**
        is the lightness and **a** is the alpha component of the HSL color.

        The saturation, value and alpha-channel values must be in the range
        0-255, and the hue value must be greater than -1.

        **See also** **getHsl** () and **setHslF** ().
        """
        ...

    def getHsl(self) -> typing.Tuple[int, int, int, int]:
        """
        https://doc.qt.io/qt-6/qcolor.html#getHsl

        **void QColor::getHsl(int * h , int * s , int * l , int * a = nullptr)
        const**

        Sets the contents pointed to by **h** , **s** , **l** , and **a** , to
        the hue, saturation, lightness, and alpha-channel (transparency)
        components of the color's HSL value.

        These components can be retrieved individually using the **hslHue** (),
        **hslSaturation** (), **lightness** () and **alpha** () functions.

        **See also** **getHslF** (), **setHsl** (), and **The HSL Color Model**
        .
        """
        ...

    def lightnessF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#lightnessF

        **float QColor::lightnessF() const**

        Returns the lightness color component of this color.

        **See also** **value** () and **getHslF** ().
        """
        ...

    def hslSaturationF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#hslSaturationF

        **float QColor::hslSaturationF() const**

        Returns the HSL saturation color component of this color.

        **See also** **hslSaturation** (), **hsvSaturationF** (), **getHslF**
        (), and **The HSL Color Model** .
        """
        ...

    def hslHueF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#hslHueF

        **float QColor::hslHueF() const**

        Returns the HSL hue color component of this color.

        **See also** **hslHue** (), **hsvHueF** (), and **getHslF** ().
        """
        ...

    def lightness(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#lightness

        **int QColor::lightness() const**

        Returns the lightness color component of this color.

        **See also** **lightnessF** () and **getHsl** ().
        """
        ...

    def hslSaturation(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#hslSaturation

        **int QColor::hslSaturation() const**

        Returns the HSL saturation color component of this color.

        **See also** **hslSaturationF** (), **hsvSaturation** (), **getHsl** (),
        and **The HSL Color Model** .
        """
        ...

    def hslHue(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#hslHue

        **int QColor::hslHue() const**

        Returns the HSL hue color component of this color.

        **See also** **hslHueF** (), **hsvHue** (), **getHsl** (), and **The HSL
        Color Model** .
        """
        ...

    def hsvSaturationF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#hsvSaturationF

        **float QColor::hsvSaturationF() const**

        Returns the HSV saturation color component of this color.

        **See also** **saturation** (), **hslSaturationF** (), **getHsvF** (),
        and **The HSV Color Model** .
        """
        ...

    def hsvHueF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#hsvHueF

        **float QColor::hsvHueF() const**

        Returns the hue color component of this color.

        **See also** **hue** (), **hslHueF** (), **getHsvF** (), and **The HSV
        Color Model** .
        """
        ...

    def hsvSaturation(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#hsvSaturation

        **int QColor::hsvSaturation() const**

        Returns the HSV saturation color component of this color.

        **See also** **saturationF** (), **hslSaturation** (), **getHsv** (),
        and **The HSV Color Model** .
        """
        ...

    def hsvHue(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#hsvHue

        **int QColor::hsvHue() const**

        Returns the HSV hue color component of this color.

        **See also** **hueF** (), **hslHue** (), **getHsv** (), and **The HSV
        Color Model** .
        """
        ...

    def darker(self, factor: int = ...) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#darker

        **QColor QColor::darker(int factor = 200) const**

        Returns a darker (or lighter) color, but does not change this object.

        If the **factor** is greater than 100, this functions returns a darker
        color. Setting **factor** to 300 returns a color that has one-third the
        brightness. If the **factor** is less than 100, the return color is
        lighter, but we recommend using the **lighter** () function for this
        purpose. If the **factor** is 0 or negative, the return value is
        unspecified.

        The function converts the current color to HSV, divides the value (V)
        component by **factor** and converts the color back to it's original
        color spec.

        **See also** **lighter** () and **isValid** ().
        """
        ...

    def lighter(self, factor: int = ...) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#lighter

        **QColor QColor::lighter(int factor = 150) const**

        Returns a lighter (or darker) color, but does not change this object.

        If the **factor** is greater than 100, this functions returns a lighter
        color. Setting **factor** to 150 returns a color that is 50% brighter.
        If the **factor** is less than 100, the return color is darker, but we
        recommend using the **darker** () function for this purpose. If the
        **factor** is 0 or negative, the return value is unspecified.

        The function converts the current color to HSV, multiplies the value (V)
        component by **factor** and converts the color back to it's original
        color spec.

        **See also** **darker** () and **isValid** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcolor.html#isValid

        **bool QColor::isValid() const**

        Returns `true` if the color is valid; otherwise returns `false`.
        """
        ...

    @staticmethod
    def fromCmykF(
        c: float, m: float, y: float, k: float, alpha: float = ...
    ) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#fromCmykF

        **[static] QColor QColor::fromCmykF(float c , float m , float y , float
        k , float a = 1.0)**

        This is an overloaded function.

        Static convenience function that returns a **QColor**  constructed from
        the given CMYK color values: **c** (cyan), **m** (magenta), **y**
        (yellow), **k** (black), and **a** (alpha-channel, i.e. transparency).

        All the values must be in the range 0.0-1.0.

        **See also** **toCmyk** (), **fromCmyk** (), **isValid** (), and **The
        CMYK Color Model** .
        """
        ...

    @staticmethod
    def fromCmyk(c: int, m: int, y: int, k: int, alpha: int = ...) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#fromCmyk

        **[static] QColor QColor::fromCmyk(int c , int m , int y , int k , int a
        = 255)**

        Static convenience function that returns a **QColor**  constructed from
        the given CMYK color values: **c** (cyan), **m** (magenta), **y**
        (yellow), **k** (black), and **a** (alpha-channel, i.e. transparency).

        All the values must be in the range 0-255.

        **See also** **toCmyk** (), **fromCmykF** (), **isValid** (), and **The
        CMYK Color Model** .
        """
        ...

    @staticmethod
    def fromHsvF(h: float, s: float, v: float, alpha: float = ...) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#fromHsvF

        **[static] QColor QColor::fromHsvF(float h , float s , float v , float a
        = 1.0)**

        This is an overloaded function.

        Static convenience function that returns a **QColor**  constructed from
        the HSV color values, **h** (hue), **s** (saturation), **v** (value),
        and **a** (alpha-channel, i.e. transparency).

        All the values must be in the range 0.0-1.0.

        **See also** **toHsv** (), **fromHsv** (), **isValid** (), and **The HSV
        Color Model** .
        """
        ...

    @staticmethod
    def fromHsv(h: int, s: int, v: int, alpha: int = ...) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#fromHsv

        **[static] QColor QColor::fromHsv(int h , int s , int v , int a = 255)**

        Static convenience function that returns a **QColor**  constructed from
        the HSV color values, **h** (hue), **s** (saturation), **v** (value),
        and **a** (alpha-channel, i.e. transparency).

        The value of **s** , **v** , and **a** must all be in the range 0-255;
        the value of **h** must be in the range 0-359.

        **See also** **toHsv** (), **fromHsvF** (), **isValid** (), and **The
        HSV Color Model** .
        """
        ...

    @staticmethod
    def fromRgbF(r: float, g: float, b: float, alpha: float = ...) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#fromRgbF

        **[static] QColor QColor::fromRgbF(float r , float g , float b , float a
        = 1.0)**

        Static convenience function that returns a **QColor**  constructed from
        the RGB color values, **r** (red), **g** (green), **b** (blue), and
        **a** (alpha-channel, i.e. transparency).

        The alpha value must be in the range 0.0-1.0. If any of the other values
        are outside the range of 0.0-1.0 the color model will be set as
        `ExtendedRgb`.

        **See also** **fromRgb** (), **fromRgba64** (), **toRgb** (), and
        **isValid** ().
        """
        ...

    @staticmethod
    def fromRgba(rgba: int) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#fromRgba

        **[static] QColor QColor::fromRgba(QRgb rgba )**

        Static convenience function that returns a **QColor**  constructed from
        the given **QRgb**  value **rgba**.

        Unlike the **fromRgb** () function, the alpha-channel specified by the
        given **QRgb**  value is included.

        **See also** **fromRgb** (), **fromRgba64** (), and **isValid** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromRgb(rgb: int) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#fromRgb

        **[static] QColor QColor::fromRgb(QRgb rgb )**

        Static convenience function that returns a **QColor**  constructed from
        the given **QRgb**  value **rgb**.

        The alpha component of **rgb** is ignored (i.e. it is automatically set
        to 255), use the **fromRgba** () function to include the alpha-channel
        specified by the given **QRgb**  value.

        **See also** **fromRgba** (), **fromRgbF** (), **toRgb** (), and
        **isValid** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromRgb(r: int, g: int, b: int, alpha: int = ...) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#fromRgb-1

        **[static] QColor QColor::fromRgb(int r , int g , int b , int a = 255)**

        Static convenience function that returns a **QColor**  constructed from
        the RGB color values, **r** (red), **g** (green), **b** (blue), and
        **a** (alpha-channel, i.e. transparency).

        All the values must be in the range 0-255.

        **See also** **toRgb** (), **fromRgba64** (), **fromRgbF** (), and
        **isValid** ().
        """
        ...

    def convertTo(self, colorSpec: "QColor.Spec") -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#convertTo

        **QColor QColor::convertTo(QColor::Spec colorSpec ) const**

        Creates a copy of **this** color in the format specified by
        **colorSpec**.

        **See also** **spec** (), **toCmyk** (), **toHsv** (), **toRgb** (), and
        **isValid** ().
        """
        ...

    def toCmyk(self) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#toCmyk

        **QColor QColor::toCmyk() const**

        Creates and returns a CMYK **QColor**  based on this color.

        **See also** **fromCmyk** (), **convertTo** (), **isValid** (), and
        **The CMYK Color Model** .
        """
        ...

    def toHsv(self) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#toHsv

        **QColor QColor::toHsv() const**

        Creates and returns an HSV **QColor**  based on this color.

        **See also** **fromHsv** (), **convertTo** (), **isValid** (), and **The
        HSV Color Model** .
        """
        ...

    def toRgb(self) -> "QColor":
        """
        https://doc.qt.io/qt-6/qcolor.html#toRgb

        **QColor QColor::toRgb() const**

        Create and returns an RGB **QColor**  based on this color.

        **See also** **fromRgb** (), **convertTo** (), and **isValid** ().
        """
        ...

    def setCmykF(
        self, c: float, m: float, y: float, k: float, alpha: float = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setCmykF

        **void QColor::setCmykF(float c , float m , float y , float k , float a
        = 1.0)**

        This is an overloaded function.

        Sets the color to CMYK values, **c** (cyan), **m** (magenta), **y**
        (yellow), **k** (black), and **a** (alpha-channel, i.e. transparency).

        All the values must be in the range 0.0-1.0.

        **See also** **getCmykF** (), **setCmyk** (), and **The CMYK Color
        Model** .
        """
        ...

    def getCmykF(self) -> typing.Tuple[float, float, float, float, float]:
        """
        https://doc.qt.io/qt-6/qcolor.html#getCmykF

        **void QColor::getCmykF(float * c , float * m , float * y , float * k ,
        float * a = nullptr) const**

        Sets the contents pointed to by **c** , **m** , **y** , **k** , and
        **a** , to the cyan, magenta, yellow, black, and alpha-channel
        (transparency) components of the color's CMYK value.

        These components can be retrieved individually using the **cyanF** (),
        **magentaF** (), **yellowF** (), **blackF** () and **alphaF** ()
        functions.

        **See also** **setCmykF** () and **The CMYK Color Model** .
        """
        ...

    def setCmyk(self, c: int, m: int, y: int, k: int, alpha: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setCmyk

        **void QColor::setCmyk(int c , int m , int y , int k , int a = 255)**

        Sets the color to CMYK values, **c** (cyan), **m** (magenta), **y**
        (yellow), **k** (black), and **a** (alpha-channel, i.e. transparency).

        All the values must be in the range 0-255.

        **See also** **getCmyk** (), **setCmykF** (), and **The CMYK Color
        Model** .
        """
        ...

    def getCmyk(self) -> typing.Tuple[int, int, int, int, int]:
        """
        https://doc.qt.io/qt-6/qcolor.html#getCmyk

        **void QColor::getCmyk(int * c , int * m , int * y , int * k , int * a =
        nullptr) const**

        Sets the contents pointed to by **c** , **m** , **y** , **k** , and
        **a** , to the cyan, magenta, yellow, black, and alpha-channel
        (transparency) components of the color's CMYK value.

        These components can be retrieved individually using the **cyan** (),
        **magenta** (), **yellow** (), **black** () and **alpha** () functions.

        **See also** **setCmyk** () and **The CMYK Color Model** .
        """
        ...

    def blackF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#blackF

        **float QColor::blackF() const**

        Returns the black color component of this color.

        **See also** **black** (), **getCmykF** (), and **The CMYK Color Model**
        .
        """
        ...

    def yellowF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#yellowF

        **float QColor::yellowF() const**

        Returns the yellow color component of this color.

        **See also** **yellow** (), **getCmykF** (), and **The CMYK Color
        Model** .
        """
        ...

    def magentaF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#magentaF

        **float QColor::magentaF() const**

        Returns the magenta color component of this color.

        **See also** **magenta** (), **getCmykF** (), and **The CMYK Color
        Model** .
        """
        ...

    def cyanF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#cyanF

        **float QColor::cyanF() const**

        Returns the cyan color component of this color.

        **See also** **cyan** (), **getCmykF** (), and **The CMYK Color Model**
        .
        """
        ...

    def black(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#black

        **int QColor::black() const**

        Returns the black color component of this color.

        **See also** **blackF** (), **getCmyk** (), and **The CMYK Color Model**
        .
        """
        ...

    def yellow(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#yellow

        **int QColor::yellow() const**

        Returns the yellow color component of this color.

        **See also** **yellowF** (), **getCmyk** (), and **The CMYK Color
        Model** .
        """
        ...

    def magenta(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#magenta

        **int QColor::magenta() const**

        Returns the magenta color component of this color.

        **See also** **magentaF** (), **getCmyk** (), and **The CMYK Color
        Model** .
        """
        ...

    def cyan(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#cyan

        **int QColor::cyan() const**

        Returns the cyan color component of this color.

        **See also** **cyanF** (), **getCmyk** (), and **The CMYK Color Model**
        .
        """
        ...

    def setHsvF(self, h: float, s: float, v: float, alpha: float = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setHsvF

        **void QColor::setHsvF(float h , float s , float v , float a = 1.0)**

        Sets a HSV color value; **h** is the hue, **s** is the saturation, **v**
        is the value and **a** is the alpha component of the HSV color.

        All the values must be in the range 0.0-1.0.

        **See also** **getHsvF** (), **setHsv** (), and **The HSV Color Model**
        .
        """
        ...

    def getHsvF(self) -> typing.Tuple[float, float, float, float]:
        """
        https://doc.qt.io/qt-6/qcolor.html#getHsvF

        **void QColor::getHsvF(float * h , float * s , float * v , float * a =
        nullptr) const**

        Sets the contents pointed to by **h** , **s** , **v** , and **a** , to
        the hue, saturation, value, and alpha-channel (transparency) components
        of the color's HSV value.

        These components can be retrieved individually using the **hueF** (),
        **saturationF** (), **valueF** () and **alphaF** () functions.

        **See also** **setHsv** () and **The HSV Color Model** .
        """
        ...

    def setHsv(self, h: int, s: int, v: int, alpha: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setHsv

        **void QColor::setHsv(int h , int s , int v , int a = 255)**

        Sets a HSV color value; **h** is the hue, **s** is the saturation, **v**
        is the value and **a** is the alpha component of the HSV color.

        The saturation, value and alpha-channel values must be in the range
        0-255, and the hue value must be greater than -1.

        **See also** **getHsv** (), **setHsvF** (), and **The HSV Color Model**
        .
        """
        ...

    def getHsv(self) -> typing.Tuple[int, int, int, int]:
        """
        https://doc.qt.io/qt-6/qcolor.html#getHsv

        **void QColor::getHsv(int * h , int * s , int * v , int * a = nullptr)
        const**

        Sets the contents pointed to by **h** , **s** , **v** , and **a** , to
        the hue, saturation, value, and alpha-channel (transparency) components
        of the color's HSV value.

        These components can be retrieved individually using the **hue** (),
        **saturation** (), **value** () and **alpha** () functions.

        **See also** **setHsv** () and **The HSV Color Model** .
        """
        ...

    def valueF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#valueF

        **float QColor::valueF() const**

        Returns the value color component of this color.

        **See also** **value** (), **getHsvF** (), and **The HSV Color Model** .
        """
        ...

    def saturationF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#saturationF

        **float QColor::saturationF() const**

        Returns the HSV saturation color component of this color.

        The color is implicitly converted to HSV.

        **See also** **hsvSaturationF** (), **hslSaturationF** (),
        **saturation** (), **getHsvF** (), and **The HSV Color Model** .
        """
        ...

    def hueF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#hueF

        **float QColor::hueF() const**

        Returns the HSV hue color component of this color.

        The color is implicitly converted to HSV.

        **See also** **hsvHueF** (), **hslHueF** (), **hue** (), **getHsvF** (),
        and **The HSV Color Model** .
        """
        ...

    def value(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#value

        **int QColor::value() const**

        Returns the value color component of this color.

        **See also** **valueF** (), **getHsv** (), and **The HSV Color Model** .
        """
        ...

    def saturation(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#saturation

        **int QColor::saturation() const**

        Returns the HSV saturation color component of this color.

        The color is implicitly converted to HSV.

        **See also** **hsvSaturation** (), **hslSaturation** (), **saturationF**
        (), **getHsv** (), and **The HSV Color Model** .
        """
        ...

    def hue(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#hue

        **int QColor::hue() const**

        Returns the HSV hue color component of this color.

        The color is implicitly converted to HSV.

        **See also** **hsvHue** (), **hslHue** (), **hueF** (), **getHsv** (),
        and **The HSV Color Model** .
        """
        ...

    def rgb(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#rgb

        **QRgb QColor::rgb() const**

        Returns the RGB value of the color. The alpha value is opaque.

        **See also** **setRgb** (), **getRgb** (), and **rgba** ().
        """
        ...

    def setRgba(self, rgba: int) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setRgba

        **void QColor::setRgba(QRgb rgba )**

        Sets the RGB value to **rgba** , including its alpha.

        **See also** **rgba** (), **rgb** (), and **setRgba64** ().
        """
        ...

    def rgba(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#rgba

        **QRgb QColor::rgba() const**

        Returns the RGB value of the color, including its alpha.

        For an invalid color, the alpha value of the returned color is
        unspecified.

        **See also** **setRgba** (), **rgb** (), and **rgba64** ().
        """
        ...

    def setRgbF(self, r: float, g: float, b: float, alpha: float = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setRgbF

        **void QColor::setRgbF(float r , float g , float b , float a = 1.0)**

        Sets the color channels of this color to **r** (red), **g** (green),
        **b** (blue) and **a** (alpha, transparency).

        The alpha value must be in the range 0.0-1.0. If any of the other values
        are outside the range of 0.0-1.0 the color model will be set as
        `ExtendedRgb`.

        **See also** **rgb** (), **getRgbF** (), and **setRgb** ().
        """
        ...

    def getRgbF(self) -> typing.Tuple[float, float, float, float]:
        """
        https://doc.qt.io/qt-6/qcolor.html#getRgbF

        **void QColor::getRgbF(float * r , float * g , float * b , float * a =
        nullptr) const**

        Sets the contents pointed to by **r** , **g** , **b** , and **a** , to
        the red, green, blue, and alpha-channel (transparency) components of the
        color's RGB value.

        These components can be retrieved individually using the **redF** (),
        **greenF** (), **blueF** () and **alphaF** () functions.

        **See also** **rgb** () and **setRgb** ().
        """
        ...

    @typing.overload
    def setRgb(self, r: int, g: int, b: int, alpha: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setRgb

        **void QColor::setRgb(int r , int g , int b , int a = 255)**

        Sets the RGB value to **r** , **g** , **b** and the alpha value to
        **a**.

        All the values must be in the range 0-255.

        **See also** **rgb** (), **getRgb** (), and **setRgbF** ().
        """
        ...

    @typing.overload
    def setRgb(self, rgb: int) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setRgb-1

        **void QColor::setRgb(QRgb rgb )**

        This is an overloaded function.

        Sets the RGB value to **rgb**. The alpha value is set to opaque.
        """
        ...

    def getRgb(self) -> typing.Tuple[int, int, int, int]:
        """
        https://doc.qt.io/qt-6/qcolor.html#getRgb

        **void QColor::getRgb(int * r , int * g , int * b , int * a = nullptr)
        const**

        Sets the contents pointed to by **r** , **g** , **b** , and **a** , to
        the red, green, blue, and alpha-channel (transparency) components of the
        color's RGB value.

        These components can be retrieved individually using the **red** (),
        **green** (), **blue** () and **alpha** () functions.

        **See also** **rgb** () and **setRgb** ().
        """
        ...

    def setBlueF(self, blue: float) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setBlueF

        **void QColor::setBlueF(float blue )**

        Sets the blue color component of this color to **blue**. If **blue**
        lies outside the 0.0-1.0 range, the color model will be changed to
        `ExtendedRgb`.

        **See also** **blueF** (), **blue** (), and **setRgbF** ().
        """
        ...

    def setGreenF(self, green: float) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setGreenF

        **void QColor::setGreenF(float green )**

        Sets the green color component of this color to **green**. If **green**
        lies outside the 0.0-1.0 range, the color model will be changed to
        `ExtendedRgb`.

        **See also** **greenF** (), **green** (), and **setRgbF** ().
        """
        ...

    def setRedF(self, red: float) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setRedF

        **void QColor::setRedF(float red )**

        Sets the red color component of this color to **red**. If **red** lies
        outside the 0.0-1.0 range, the color model will be changed to
        `ExtendedRgb`.

        **See also** **redF** (), **red** (), and **setRgbF** ().
        """
        ...

    def blueF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#blueF

        **float QColor::blueF() const**

        Returns the blue color component of this color.

        **See also** **setBlueF** (), **blue** (), and **getRgbF** ().
        """
        ...

    def greenF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#greenF

        **float QColor::greenF() const**

        Returns the green color component of this color.

        **See also** **setGreenF** (), **green** (), and **getRgbF** ().
        """
        ...

    def redF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#redF

        **float QColor::redF() const**

        Returns the red color component of this color.

        **See also** **setRedF** (), **red** (), and **getRgbF** ().
        """
        ...

    def setBlue(self, blue: int) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setBlue

        **void QColor::setBlue(int blue )**

        Sets the blue color component of this color to **blue**. Integer
        components are specified in the range 0-255.

        **See also** **blue** (), **blueF** (), and **setRgb** ().
        """
        ...

    def setGreen(self, green: int) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setGreen

        **void QColor::setGreen(int green )**

        Sets the green color component of this color to **green**. Integer
        components are specified in the range 0-255.

        **See also** **green** (), **greenF** (), and **setRgb** ().
        """
        ...

    def setRed(self, red: int) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setRed

        **void QColor::setRed(int red )**

        Sets the red color component of this color to **red**. Integer
        components are specified in the range 0-255.

        **See also** **red** (), **redF** (), and **setRgb** ().
        """
        ...

    def blue(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#blue

        **int QColor::blue() const**

        Returns the blue color component of this color.

        **See also** **setBlue** (), **blueF** (), and **getRgb** ().
        """
        ...

    def green(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#green

        **int QColor::green() const**

        Returns the green color component of this color.

        **See also** **setGreen** (), **greenF** (), and **getRgb** ().
        """
        ...

    def red(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#red

        **int QColor::red() const**

        Returns the red color component of this color.

        **See also** **setRed** (), **redF** (), and **getRgb** ().
        """
        ...

    def setAlphaF(self, alpha: float) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setAlphaF

        **void QColor::setAlphaF(float alpha )**

        Sets the alpha of this color to **alpha**. float alpha is specified in
        the range 0.0-1.0.

        **See also** **alphaF** (), **alpha** (), and **Alpha-Blended Drawing**
        .
        """
        ...

    def alphaF(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolor.html#alphaF

        **float QColor::alphaF() const**

        Returns the alpha color component of this color.

        **See also** **setAlphaF** (), **alpha** (), and **Alpha-Blended
        Drawing** .
        """
        ...

    def setAlpha(self, alpha: int) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setAlpha

        **void QColor::setAlpha(int alpha )**

        Sets the alpha of this color to **alpha**. Integer alpha is specified in
        the range 0-255.

        **See also** **alpha** (), **alphaF** (), and **Alpha-Blended Drawing**
        .
        """
        ...

    def alpha(self) -> int:
        """
        https://doc.qt.io/qt-6/qcolor.html#alpha

        **int QColor::alpha() const**

        Returns the alpha color component of this color.

        **See also** **setAlpha** (), **alphaF** (), and **Alpha-Blended
        Drawing** .
        """
        ...

    def spec(self) -> "QColor.Spec":
        """
        https://doc.qt.io/qt-6/qcolor.html#spec

        **QColor::Spec QColor::spec() const**

        Returns how the color was specified.

        **See also** **Spec**  and **convertTo** ().
        """
        ...

    @staticmethod
    def colorNames() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qcolor.html#colorNames

        **[static] QStringList QColor::colorNames()**

        Returns a **QStringList**  containing the color names Qt knows about.

        **See also** **Predefined Colors** .
        """
        ...

    def setNamedColor(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qcolor.html#setNamedColor

        **void QColor::setNamedColor(const QString & name )**

        Sets the RGB value of this **QColor**  to **name** , which may be in one
        of these formats:

        * #RGB (each of R, G, and B is a single hex digit)
          * #RRGGBB
          *
        #AARRGGBB (Since 5.2)
          * #RRRGGGBBB
          * #RRRRGGGGBBBB
          * A name from
        the list of colors defined in the list of **SVG color keyword names**
        provided by the World Wide Web Consortium; for example, "steelblue" or
        "gainsboro". These color names work on all platforms. Note that these
        color names are **not** the same as defined by the **Qt::GlobalColor**
        enums, e.g. "green" and **Qt::green**  does not refer to the same color.
        * `transparent` \\- representing the absence of a color.

        The color is invalid if **name** cannot be parsed.

        **See also** **QColor** (), **name** (), and **isValid** ().
        """
        ...

    def name(self, format: "QColor.NameFormat" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qcolor.html#name

        **[since 5.2] QString QColor::name(QColor::NameFormat format = HexRgb)
        const**

        Returns the name of the color in the specified **format**.

        This function was introduced in Qt 5.2.

        **See also** **setNamedColor** () and **NameFormat** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._functions import qmlRegisterUncreatableType as qmlRegisterUncreatableType
from ._functions import qmlRegisterAnonymousType as qmlRegisterAnonymousType
from ._functions import qmlRegisterSingletonInstance as qmlRegisterSingletonInstance
from ._functions import qmlRegisterRevision as qmlRegisterRevision
from ._functions import qmlAttachedPropertiesObject as qmlAttachedPropertiesObject
from ._functions import qjsEngine as qjsEngine
from ._functions import qmlEngine as qmlEngine
from ._functions import qmlContext as qmlContext
from ._functions import qmlTypeId as qmlTypeId
from ._functions import qmlRegisterType as qmlRegisterType
from ._functions import qmlRegisterType as qmlRegisterType
from ._functions import qmlRegisterSingletonType as qmlRegisterSingletonType
from ._functions import qmlRegisterSingletonType as qmlRegisterSingletonType
from ._functions import qmlRegisterModule as qmlRegisterModule
from ._functions import qmlProtectModule as qmlProtectModule
from ._functions import (
    qmlRegisterUncreatableMetaObject as qmlRegisterUncreatableMetaObject,
)
from ._functions import qmlRegisterTypeNotAvailable as qmlRegisterTypeNotAvailable
from ._functions import qmlClearTypeRegistrations as qmlClearTypeRegistrations
from ._QJSEngine import QJSEngine as QJSEngine
from ._QJSManagedValue import QJSManagedValue as QJSManagedValue
from ._QJSPrimitiveUndefined import QJSPrimitiveUndefined as QJSPrimitiveUndefined
from ._QJSPrimitiveNull import QJSPrimitiveNull as QJSPrimitiveNull
from ._QJSPrimitiveValue import QJSPrimitiveValue as QJSPrimitiveValue
from ._QJSValue import QJSValue as QJSValue
from ._QJSValueIterator import QJSValueIterator as QJSValueIterator
from ._QQmlAbstractUrlInterceptor import (
    QQmlAbstractUrlInterceptor as QQmlAbstractUrlInterceptor,
)
from ._QQmlEngine import QQmlEngine as QQmlEngine
from ._QQmlApplicationEngine import QQmlApplicationEngine as QQmlApplicationEngine
from ._QQmlComponent import QQmlComponent as QQmlComponent
from ._QQmlContext import QQmlContext as QQmlContext
from ._QQmlImageProviderBase import QQmlImageProviderBase as QQmlImageProviderBase
from ._QQmlError import QQmlError as QQmlError
from ._QQmlExpression import QQmlExpression as QQmlExpression
from ._QQmlExtensionPlugin import QQmlExtensionPlugin as QQmlExtensionPlugin
from ._QQmlEngineExtensionPlugin import (
    QQmlEngineExtensionPlugin as QQmlEngineExtensionPlugin,
)
from ._QQmlFileSelector import QQmlFileSelector as QQmlFileSelector
from ._QQmlIncubator import QQmlIncubator as QQmlIncubator
from ._QQmlIncubationController import (
    QQmlIncubationController as QQmlIncubationController,
)
from ._QQmlListReference import QQmlListReference as QQmlListReference
from ._QQmlNetworkAccessManagerFactory import (
    QQmlNetworkAccessManagerFactory as QQmlNetworkAccessManagerFactory,
)
from ._QQmlParserStatus import QQmlParserStatus as QQmlParserStatus
from ._QQmlProperty import QQmlProperty as QQmlProperty
from ._QQmlPropertyMap import QQmlPropertyMap as QQmlPropertyMap
from ._QQmlPropertyValueSource import QQmlPropertyValueSource as QQmlPropertyValueSource
from ._QQmlScriptString import QQmlScriptString as QQmlScriptString
